%define _noVersionedDependencies 1
%define _minimum_patches 0
%define _apply_drm_patches 1

%if "%{?_dist_release}" > "vl6"
%global kmod kmod
%else
%global kmod module-init-tools
%endif

Summary: The Linux kernel (the core of the Linux operating system)
Summary(ja): Linux カーネル (Linux オペレーティングシステムの心臓部分)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
%define buildpae 0
%define builddoc 0
%define buildsource 0

%define with_headers 1
%define with_firmware 0

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 4
%define patchlevel 9
%define kversion 3.%{sublevel}
%define rpmversion 3.%{sublevel}.%{patchlevel}
%define release 1%{?_dist_release}

%define make_target bzImage
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%define KVERREL %{rpmversion}-%{release}

# groups of related archs
%define all_x86 i686
%define all_ppc ppciseries ppcpseries ppc ppc64

# Override generic defaults with per-arch defaults 

# don't build noarch kernels or headers
%ifarch noarch
%define builddoc 1
%define buildsource 1
%define buildup 0
%define buildpae 0
%define with_headers 0
%define with_firmware 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-*.config
%endif

%ifarch i686
%define buildpae 1
%endif

# build x86 headers on i686 build
# build noarch package with i686 build
%ifarch i686
%define with_headers 1
%define buildsource 1
%define builddoc 1
%define with_firmware 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i686*.config
%define image_install_path boot
%define hdrarch i386
%define asmarch x86
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%define asmarch x86
%endif

%ifarch ppc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define make_target bzImage zImage.stub
%define hdrarch powerpc
%define asmarch powerpc
%endif

%ifarch ppc64iseries
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define make_target bzImage
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%endif

%ifarch sparc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%define asmarch sparc
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config
%define image_install_path boot
%define make_target vmlinux
%define hdrarch powerpc
%define asmarch powerpc
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64.config
%define image_install_path boot/efi/EFI/redhat
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, kudzu <= 0.92, initscripts < 6.51, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0 ipw2200-firmware < 2.3 selinux-policy-targeted < 1.23.16-1

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
#
%define kernel_headers_conflicts libdrm-devel < 2.4.0-4

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, %{kmod}, initscripts >= 8.80, mkinitrd >= 6.0.93, linux-firmware >= 20110601-1

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
ExclusiveArch: noarch i686 x86_64 %{all_ppc}
ExclusiveOS: Linux
Provides: kernel = %{rpmversion}
Provides: kernel26 = %{rpmversion}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 16
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: alsa-driver = 1.0.20
Requires(pre): %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
#
# List the packages used during the kernel build
#
BuildRequires: %{kmod}
BuildRequires: patch >= 2.5.4, bash >= 2.03, tar
BuildRequires: coreutils
BuildRequires: bzip2, gzip, xz
BuildRequires: xz-lzma-compat
BuildRequires: findutils, m4, perl, make >= 3.78, gnupg, diffutils
BuildRequires: net-tools
BuildRequires: gcc >= 3.3.5, binutils >= 2.15

Vendor:		Project Vine
Distribution:	Vine Linux
Packager:	daisuke, shaolin, iwamoto

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v3.x/linux-%{kversion}.tar.xz

Source10: COPYING.modules
Source11: genkey

Source21: kernel-%{kversion}-i686.config
Source22: kernel-%{kversion}-i686-pae.config
Source23: kernel-%{kversion}-x86_64.config
Source32: kernel-%{kversion}-ppc.config


# Source 100 - 500 for Vine Linux
# fb boot logo
Source100: logo_vine_clut224.ppm

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
%if %{patchlevel}
Patch1: patch-%{kversion}.%{patchlevel}.xz
%endif

# Patches 100 through 500 are meant for architecture patches

# 200 - 299   x86(-64)

# atom errata
# Patch280: linux-2.6-x86-workaround-failures-on-intel-atom.patch


# 300 - 399   ppc(64)
Patch350: linux-2.6.23-windtunnel-printk.patch

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch800: linux-2.6-build-nonintconfig.patch

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

# NIC driver updates

Patch1394: linux-2.6-zd1211rw-gw-us54gxs.patch

# tg3 add new id (57766,5778[26])
Patch1430: linux-3.4.7-tg3-support-newid.patch

# Misc bits.
Patch1610: linux-2.6.23-atkbd-dell-multimedia.patch
Patch1630: linux-2.6.23-module_version.patch
Patch1650: linux-2.6-input-kill-stupid-messages.patch
Patch1770: linux-2.6-valid-ether-addr.patch
Patch1830: linux-2.6-w1-hush-debug.patch
Patch1840: linux-2.6-defaults-pci_no_msi.patch
Patch1850: linux-2.6-silence-fbcon-logo.patch
Patch1860: linux-2.6-silence-acpi-blacklist.patch
Patch1890: linux-2.6.35-mmc-sdhci-update.patch

Patch1900: linux-2.6.35-quirk-lenovo-itpm.patch

# initial MBA Mid2011 hacky support
Patch1910: linux-3.0.4_macbookair_middle2011_fixedmode_hackyhack.patch


# VM bits
Patch2001: linux-2.6-vm-silence-atomic-alloc-failures.patch

# IDE
Patch2010: linux-3.2-ide-piix-prefer-ata_piix.patch

# SCSI
Patch2301: linux-2.6.23-VMWare5-fix-LSI_emulation.patch
Patch2504: linux-2.6-at76.patch

# DRM
# drm update from ubuntu maverick kernel
Patch2700: linux-2.6.35-drm-update.patch
# ignore invalid EDID extensions
# https://bugs.freedesktop.org/show_bug.cgi?id=31154
Patch2710: linux-2.6-drm-ignore-invalid-EDID-extensions.patch



#
# External drivers that are about to get accepted upstream
#



#
# 6000 to 10000 is for Vine Linux
#

# unionfs 2.5.10
# http://www.am-utils.org/project-unionfs.html
Patch6030: unionfs-2.5.10_for_3.2.patch
Patch6031: unionfs-2.5.8-open-unlink-ftruncate-crash-fix.patch

# aufs3
Patch6100: linux-3.4-aufs3.patch
#Patch6101: linux-3.2-aufs3-proc_map.patch

#
# TuxOnIce (formerly suspend2) patch
%define tuxonice_version 3.2.1-for-linux-3.4
Patch9000: tuxonice-%{tuxonice_version}.patch
#Patch9010: tuxonice-build-fix-on-powerpc.patch

#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here. 
# Not patches you're too lazy for to put in the proper place.
#
Patch10000: linux-2.6-LINUX_COMPILER-LANG_C.patch

# Security fix patches


# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description -l ja
kernel パッケージには、Linux オペレーティングシステムの心臓部分とも
いえる Linux カーネル (vmlinuz) が含まれています。
カーネルは，メモリ管理，プロセス管理，デバイスの入出力等，オペレーティング
システムの基本的な部分を司ります。

%package devel
Summary: Development package for building kernel modules to match the kernel.
Summary(ja): 特定のバージョンのカーネル用のモジュールを構築するための開発パッケージ
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel26-devel-%{_target_cpu} = %{rpmversion}-%{release}

%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

### kernel-source
%package source
Summary: The source code for the Linux kernel.
Summary(ja): Linux カーネルのソースコード
Group: Development/Libraries
BuildArch: noarch
Requires(pre): fileutils
Requires: make >= 3.78
Requires: gcc >= 3.2
Requires: binutils
# documentations
Requires: kernel-doc = %{rpmversion}-%{release}
# for menuconfig
Requires: ncurses-devel readline-devel
# for gconfig
#Requires: gtk2-devel
# for xconfig
#Requires: qt-devel

%description source
The kernel-source package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is
smaller due only including drivers for your particular hardware, if you are
so inclined (and you know what you're doing). The customisation guide in the
documentation describes in detail how to do this. This package is neither
needed nor usable for building external kernel modules for linking into the
default kernel.

If you use "gconfig" to configure the kernel, install gtk2-devel package.
If you use "xconfig" to configure the kernel, install qt-devel package.

%description source -l ja
kernel-source パッケージには Linux カーネルのソースコードが含まれて
います．カーネルのソースコードは多くの C プログラムの作成に必要です．
カーネルのソースコードに定義されている制限に依存することがあるからです．
このソースコードを使って，あなたのシステム向けにチューンアップした
カスタムカーネルを作成することもできます．

"gconfig" をつかってカーネルのコンフィグレーションを行う場合は、gtk2-devel
パッケージをインストールしてください。
"xconfig" をつかってカーネルのコンフィグレーションを行う場合は、qt-devel
パッケージをインストールしてください。

### kernel-doc
%package doc
Summary: Various documentation bits found in the kernel source.
Summary(ja): カーネルソース内のさまざまなドキュメント群
Group: Applications/Documentation
BuildArch: noarch

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%description doc -l ja
このパッケージにはカーネルソースに含まれているドキュメントが
収められています．Linux カーネルやデバイスドライバに関する様々な
情報がこのドキュメントには記されています．

Linux カーネルモジュールを読み込む際の引数を調べたい場合等，
このパッケージをインストールすると良いでしょう．

### kernel-headers
%package headers
Summary: Header files for the Linux kernel for use by glibc
Summary(ja): Linux カーネルのヘッダファイル
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
Conflicts: %{kernel_headers_conflicts}

%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%description headers -l ja
kernel-headers パッケージには、Linux カーネルとユーザスペースプログラムや
ライブラリとの間のインタフェースを規定する C ヘッダファイルが収録されて
います。ヘッダファイルではデータ構造や定数値が定義されており、多くの
プログラムをコンパイルする際に必要となります。また、glibc パッケージを
リビルドする際にも必要となるものです。

%package firmware
Summary: Firmware files used by the Linux kernel
Summary(ja): Linux kernel で使用されているファームウェア
Group: Development/System
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
BuildArch: noarch

%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%description firmware -l ja
Kernel-firmware にはいくつかのデバイスを利用するために必要なファームウェアファイルが
含まれています。

%package pae
Summary: The Linux kernel compiled for PAE capable machines.
Summary(ja): PAE 対応マシン用にコンパイルされた Linux カーネル

Group: System Environment/Kernel
Provides: kernel = %{rpmversion}
Provides: kernel26 = %{rpmversion}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}pae
Provides: alsa-driver = 1.0.20
Requires(pre): %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description pae
This package includes a version of the Linux kernel with support for up to
64GB of high memory.  It requires a CPU with Physical Address Extensions
(PAE). The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-pae package if your machine has more than 4GB of memory.

%description pae -l ja
このパッケージには 64GB までのメモリをサポートする Linux カーネルが収められて
います．このカーネルを利用するためには PAE 対応の CPU が必要です。

あなたのマシンが 4GB 以上のメモリを搭載している場合は kernel-pae パッケージを
インストールしてください．

%package pae-devel
Summary: Development package for building kernel modules to match the PAE capable kernel.
Summary(ja): 特定のバージョンのPAE対応カーネル用のモジュールを構築するための開発パッケージ
Group: System Environment/Kernel
Provides: kernel-pae-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}pae
Provides: kernel-devel = %{rpmversion}-%{release}pae
Provides: kernel26-devel = %{rpmversion}-%{release}pae
AutoReqProv: no

%description pae-devel
This package provides kernel headers and makefiles sufficient to build modules
against the PAE capable kernel package.


%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{kversion}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 
%if %{patchlevel}
%patch1 -p1
%endif

#
# Patches to back out
#

#
# Architecture patches
#

#
# x86(-64)
#

# %patch280 -p1

# 
# ppc(64)
#

%patch350 -p1

#
# ia64
#

#
# sparc/sparc64
#


#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
##VINE## %patch800 -p1

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#


#
# Make /dev/mem a need-to-know function 
#

#
# SCSI Bits.
#

# NIC driver fixes.
# add support PLANEX GW-US54GXS
##VINE## %patch1394 -p1

# tg3
%patch1430 -p1

# Misc fixes
# Make multimedia buttons on Dell Inspiron 8200 work.
%patch1610 -p1
# Add missing MODULE_VERSION tags to some modules.
##VINE## %patch1630 -p1
# The input layer spews crap no-one cares about.
%patch1650 -p1
# 
%patch1770 -p1
# Silence debug messages in w1
%patch1830 -p1
# disable PCI MSI by default
%patch1840 -p1
# dont show fbcon logo on quiet mode
%patch1850 -p1
# silence acpi blacklist code
%patch1860 -p1
# add quirk for ricoh mmc (e823)
# http://kernel.ubuntu.com/git?p=ubuntu/ubuntu-maverick.git;a=commit;h=be04c161614e57f31deae7505afcdec220a7dd1f
##VINE## %patch1880 -p1
# update sdhci driver
# add support ricoh mmc host controller (843/e823/e822)
##VINE## %patch1890 -p1
# add quirk for Lenove's TPM device to autodetect
# https://lkml.org/lkml/2011/2/15/605
##VINE## %patch1900 -p1

# initial MBA Mid2011 hacky support
%patch1910 -p1


#
# VM related fixes.
#
# Silence GFP_ATOMIC failures.
%patch2001 -p1

# IDE
# prefer ata_piix driver on ICH4+ chipset instead of IDE/piix
%patch2010 -p1

# 3w-9xxx update (2.26.02.008)
%patch2301 -p1

%patch2504 -p1

# drm fixes
%if %{_apply_drm_patches}
##VINE## %patch2700 -p1
##VINE## %patch2710 -p1
%endif

# v4l


#
# External drivers that are about to get accepted upstream
#


#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#


#
# Patches 6000 to 10000 are for Vine Linux
#

%if !%{_minimum_patches}
# unionfs
#%patch6030 -p1
##VINE## %patch6031 -p1

# aufs
%patch6100 -p1
#%patch6101 -p1

# tuxonice
%patch9000 -p1
#%patch9010 -p1
%endif

#
# final stuff
#
# do not include localized version string in /proc/version
%patch10000 -p1

# security fix


#
# misc small stuff to make things compile or otherwise improve performance
#

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

# put Vine logo
cp -f %{SOURCE100} drivers/video/logo/logo_linux_clut224.ppm

#
# install extra documentations
#
#
mkdir configs

cp -fv %{all_arch_configs} .


# now run oldconfig over all the config files
for i in *.config
do 
	mv $i .config 
	Arch=`head -1 .config | cut -b 3-`
	make ARCH=$Arch oldnoconfig
	echo "# $Arch" > configs/$i
	cat .config >> configs/$i 
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{patchlevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
# find . -name "*.orig" -exec rm -fv {} \;
# find . -name "*~" -exec rm -fv {} \;


###
### build
###
%build
sync

cd linux-%{kversion}


BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
	DevelDir=/usr/src/kernels/%{KVERREL}-$1-%{_target_cpu}
	DevelLink=/usr/src/kernels/%{KVERREL}$1-%{_target_cpu}
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
	DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
	DevelLink=
    fi

    KernelVer=%{rpmversion}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    echo CHECKING NEW CONFIG OPTIONS...
    make ARCH=$Arch listnewconfig | grep -E '^CONFIG_' > .newoptions || true
    if [ -s .newoptions ]; then
      echo NEW CONFIG OPTION FOUND.
      cat .newoptions
    else
      echo NO NEW CONFIG OPTION FOUND.
    fi
    rm -f .newoptions
    
    ##VINE## make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch oldnoconfig > /dev/null
    make -s ARCH=$Arch include/linux/version.h 

    make -s ARCH=$Arch %{?_smp_mflags} %{make_target}
    make -s ARCH=$Arch %{?_smp_mflags} modules || exit 1
    #make ARCH=$Arch buildcheck
    
    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%ifarch ppc
    cp vmlinux $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
%else
    cp arch/$Arch/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
%endif
	if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
	fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    cp modules.{order,builtin} $RPM_BUILD_ROOT/lib/modules/$KernelVer/
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc
    if [ -f arch/powerpc/lib/crtsavres.S -a -f arch/powerpc/lib/crtsavres.o ]
    then
      cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

    if test -s vmlinux.id; then
      cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id
    else
      echo >&2 "*** WARNING *** no vmlinux build ID! ***"
    fi

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif


    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames
    xargs --no-run-if-empty chmod u+x < modnames

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" `
	do
		echo -n "$i " 
		/sbin/modinfo -l $i >> modinfo
	done
    cat modinfo |\
		grep -v "^GPL" |
		grep -v "^Dual BSD/GPL" |\
		grep -v "^Dual MPL/GPL" |\
		grep -v "^GPL and additional rights" |\
		grep -v "^GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin builtin.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap devname softdep
    do
          rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    [ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildpae}
BuildKernel pae
%endif

###
### install
###

%install

cd linux-%{kversion}

# build documentation package
%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT%{_docdir}/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT%{_docdir}/kernel-doc-%{kversion}
%endif

# build source package
%if %{buildsource}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/src/linux-%{kversion}
sync
make -s mrproper
sync
tar cf - . | tar xf - -C $RPM_BUILD_ROOT%{_prefix}/src/linux-%{kversion}
rm -rf $RPM_BUILD_ROOT%{_prefix}/src/linux-%{kversion}/Documentation
ln -sf %{_docdir}/kernel-doc-%{kversion}/Documentation $RPM_BUILD_ROOT%{_prefix}/src/linux-%{kversion}/
sync

#
rm -f $RPM_BUILD_ROOT%{_prefix}/src/linux-%{kversion}/arch/x86/tools/relocs

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{kversion}/Makefile
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
%endif

%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
    sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{with_firmware}
make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware firmware_install
%endif

sync


###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre pae
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}

%ifarch ppc
for MODCONFFILE in /etc/modprobe.d/modprobe.conf.dist /etc/modprobe.conf /etc/modprobe.d/modprobe.conf
do
  if [ -f "$MODCONFFILE" ]; then
    TEMPFILE=`/bin/mktemp -q /tmp/modconffile.XXXXXX`
    sed -e 's/alias sound snd-powermac$//' $MODCONFFILE > $TEMPFILE
    cat $TEMPFILE > $MODCONFFILE
    rm -f $TEMPFILE
  fi
done
%endif

cd /boot
# vmlinuz symlinks to new default kernel
ln -sf vmlinuz-%{KVERREL} vmlinuz
%ifarch ppc
ln -sf vmlinuz-%{KVERREL} vmlinux
%endif
ln -sf System.map-%{KVERREL} System.map
ln -sf initrd-%{KVERREL}.img initrd.img
# vmlinuz.old symlink to current running kernel
current=`uname -r`
if [ ! -f vmlinuz-${current} ]; then
  ln -sf vmlinuz-%{KVERREL} vmlinuz.old
%ifarch ppc
  ln -sf vmlinuz-%{KVERREL} vmlinux.old
%endif
  ln -sf System.map-%{KVERREL} System.map.old
  ln -sf initrd-%{KVERREL}.img initrd.old.img
else
  ln -sf vmlinuz-${current} vmlinuz.old
%ifarch ppc
  ln -sf vmlinuz-${current} vmlinux.old
%endif
  ln -sf System.map-${current} System.map.old
  ln -sf initrd-${current}.img initrd.old.img
fi

[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
depmod -a -F /boot/System.map-%{KVERREL} %{KVERREL}

# if preffered bootloader is LILO, execute lilo.
%ifarch i586 i686
if [ -f /etc/sysconfig/bootloader ]; then
  source /etc/sysconfig/bootloader
  if [ "$BOOTLOADER" = "lilo" ]; then
    if [ -x /sbin/lilo -a -f /etc/lilo.conf ]; then
      /sbin/lilo > /dev/null
      exit 0
    fi
  fi
fi
%endif

# update grub/menu.lst
GRUB_MENULST="/boot/grub/menu.lst"
if [ -f $GRUB_MENULST ]; then
  if ( grep -q "resume2=" $GRUB_MENULST ) ; then
    sed -i.rpmsave 's/resume2=/resume=/g' $GRUB_MENULST
  fi
fi

%post pae
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}pae

cd /boot
# vmlinuz-pae symlinks to new default pae kernel
ln -sf vmlinuz-%{KVERREL}pae vmlinuz-pae
ln -sf System.map-%{KVERREL}pae System.map-pae
ln -sf initrd-%{KVERREL}pae.img initrd-pae.img
# vmlinuz.old symlink to current running kernel
current=`uname -r`
ln -sf vmlinuz-${current} vmlinuz.old
ln -sf System.map-${current} System.map.old
ln -sf initrd-${current}.img initrd.old.img

[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
depmod -a -F /boot/System.map-%{KVERREL}pae %{KVERREL}pae

# add PAE kernel entry to grub menu.list
GRUB_MENULST="/boot/grub/menu.lst"
if [ -f $GRUB_MENULST ]; then
  if ( ! grep -q "PAE kernel" $GRUB_MENULST ) ; then
    if [ -x /sbin/grubby ]; then
      /sbin/grubby --title="Vine Linux (PAE kernel)" \
                   --add-kernel=/boot/vmlinuz-pae \
		   --initrd=/boot/initrd-pae.img \
                   --copy-default \
		   --config-file=$GRUB_MENULST >& /dev/null ||:
    fi
  fi
fi

# if preffered bootloader is LILO, execute lilo.
%ifarch i586 i686 x86_64
if [ -f /etc/sysconfig/bootloader ]; then
  source /etc/sysconfig/bootloader
  if [ "$BOOTLOADER" = "lilo" ]; then
    if [ -x /sbin/lilo -a -f /etc/lilo.conf ]; then
      /sbin/lilo > /dev/null
      exit 0
    fi
  fi
fi
%endif

# update grub/menu.lst
GRUB_MENULST="/boot/grub/menu.lst"
if [ -f $GRUB_MENULST ]; then
  if ( grep -q "resume2=" $GRUB_MENULST ) ; then
    sed -i.rpmsave 's/resume2=/resume=/g' $GRUB_MENULST
  fi
fi

%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun pae
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}pae


###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_firmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%endif

%if %{buildup}
%files 
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/modules.*
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source

%files devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif

%if %{buildpae}
%files pae
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}pae
/boot/System.map-%{KVERREL}pae
/boot/config-%{KVERREL}pae
%dir /lib/modules/%{KVERREL}pae
/lib/modules/%{KVERREL}pae/modules.*
/lib/modules/%{KVERREL}pae/kernel
/lib/modules/%{KVERREL}pae/build
/lib/modules/%{KVERREL}pae/source

%files pae-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-pae-%{_target_cpu}
/usr/src/kernels/%{KVERREL}pae-%{_target_cpu}
%endif



# only some architecture builds need kernel-source
%if %{buildsource}
%files source
%defattr(-,root,root)
%{_prefix}/src/linux-%{kversion}
%dir %{_prefix}/src/linux-%{kversion}
%endif

# only some architecture builds need kernel-doc
%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%endif


%changelog
* Thu Aug 16 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.9-1
- upadte to 3.4.9

* Fri Aug 10 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.8-1
- update to 3.4.8
- enable BMCA and BRCMSMAC(Broadcom SoftMAC driver)

* Wed Aug 01 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.7-1
- update to 3.4.7

* Fri Jul 27 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.6-3
- add patch1430 to support tg3 newer chipsets

* Sat Jul 21 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.6-2
- add kmod to kernel_prereq (instead of module-init-tools)

* Fri Jul 20 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.6-1
- update to 3.4.6

* Wed Jul 18 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.5-1
- update to 3.4.5
- add xz, kmod, coreutils to BR:
- remove module-init-tools, sh-utils from BR:

* Wed Jul 04 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.4-2
- add modules.{order,builtin}

* Sat Jun 23 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.4-1
- update to 3.4.4

* Mon Jun 18 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.4.3-1
- update to 3.4.3
- update tuxonice/aufs3 patch

* Thu May 03 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.16-1
- update to 3.2.16

* Tue Mar 13 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.10-1
- update to 3.2.10

* Sat Mar 03 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.9-1
- update to 3.2.9

* Tue Feb 21 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.7-1
- update to 3.2.7

* Wed Feb 15 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.6-2
- update tuxonice patch (github toi-3.2 current)

* Tue Feb 14 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.6-1
- update to 3.2.6

* Sat Feb 04 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.4-1
- update to 3.2.4

* Fri Jan 27 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.2-2
- add aufs3 patch
- drop unionfs support

* Thu Jan 26 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.2-1
- update to 3.2.2

* Fri Jan 13 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.1-1
- update to 3.2.1

* Sat Jan 07 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.2.0-1
- update to 3.2
- update x86 configs
- prereq module-init-tools >= 3.16

* Thu Dec 22 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.1.6-1
- update to 3.1.6

* Tue Nov 29 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.1.4-1
- update to 3.1.4

* Mon Nov 28 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.1.3-1
- update to 3.1.3
  - update x86 configs
- update tuxonice to current
- drop patch1421,1422

* Mon Oct 24 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.8-1
- update to 3.0.8

* Mon Oct 24 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.7-1
- update to 3.0.7

* Wed Oct 12 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.4-4
- update unionfs to 2.5.10
- update configs (enable more drivers and functions)
  SCHED_AUTOGROUP NL80211_TESTMODE BLK_DEV_RBD SCSI_CXGB4_ISCSI
  SCSI_BNX2X_FCOE SCSI_ISCI STMMAC_ETH STMMAC_DUAL_MAC PCH_GBE BNA
  PCMCIA_RAYCS ATH9K_PCI ATH9K_AHB CARL9170 CARL9170_LEDS CARL9170_WPC
  B43_PHY_N IWLWIFI_DEVICE_SVTOOL RTL8192CE RTL8192SE RTL8192CU RTLWIFI
  RTL8192C_COMMON WL12XX_MENU WL12XX WL12XX_HT WL12XX_SDIO MWIFIEX
  MWIFIEX_SDIO USB_NET_CX82310_ETH USB_NET_KALMIA USB_VL600
  XEN_NETDEV_BACKEND IR_ENE IR_MCEUSB IR_ITE_CIR IR_FINTEK IR_NUVOTON
  IR_REDRAT3 IR_STREAMZAP IR_WINBOND_CIR RC_LOOPBACK USBIP_CORE
  USBIP_VHCI_HCD USBIP_HOST R8187SE RTL8192U RTL8192E R8712U R8712_AP
  RTS_PSTOR DRM_PSB INTEL_MEI ACERHDF DELL_WMI_AIO HP_ACCEL
  IDEAPAD_LAPTOP INTEL_IPS FANOTIFY

* Sat Sep 17 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 3.0.4-3
- add Patch1421 & Patch1422
  (based on patches found at http://almostsure.com/mba42/ and fixed a bit)

* Fri Sep 16 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 3.0.4-2
- add Patch1420 - a hack to support MBA Mid2011 LCD
  (inspired from: https://bugs.freedesktop.org/show_bug.cgi?id=39533)

* Tue Aug 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.4-1
- update to 3.0.4

* Fri Aug 19 2011 Daisuke SUZUKI <daisuke@linux.or.jp> - 3.0.3-1
- update to 3.0.3
- udpate configs
  - build legacy IDE drivers as module
  - enable new drivers

* Mon Aug 15 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 3.0.1-3
- add Patch9010 to fix build failure on ppc

* Sun Aug 14 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 3.0.1-2
- more config updates (enable some staging drivers found on compat-wireless)
- TODO: configs - more review & fix needed

* Sun Aug 14 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 3.0.1-1
- inital attempt for 3.0.1
- disable obsolete/already_merged_into_upstream patches
- s/nonint_oldconfig/oldnoconfig/
- tuxonice: current-tuxonice-for-3.0.patch.bz2 (as of Aug. 14, 2011)
- unionfs: 2.5.9.2_for_3.0.0-rc4
- fix configs from m to y for the followings:
  INTEL_IDLE, BT_L2CAP, BT_SCO, LEDS_CLASS

* Tue Jul 05 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-20
- add patch1890 to update sdhci driver (ricoh mmc support)
- add patch1900 to add quirk for lenove iTPM devices
- update Patch2700 (drm patch)

* Fri Jul 01 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-19
- add patch1870 to recognize ALPS Touchpad on Dell E6510
- add patch1880 to support newer ricoh mmc hosts
- add patch1410 to support iwlwifi new ucode loading
- disable kernel-firmware build and require linux-firmware instead.

* Mon May 16 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-18
- update configs
  - disable PCI MSI by default (CONFIG_PCI_MSI_DEFAULT_ON)

* Sun May 15 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-17
- update to unionfs 2.5.9.1
- update to tuxonice 3.2
- update configs
- remove ppc64 config

* Sat May 14 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-16
- add Patch2700 to update drm
- add Patch2710 to ignore invalid edid extensions

* Wed May 11 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-15
- add patch1400 to update e1000e driver

* Sat Apr 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-14
- drop i586 config
- build kernel-{source,doc,firmware}.noarch package on i686 build

* Sat Apr 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-13
- update to 2.6.35.13

* Wed Apr 27 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-12
- update configs
  - enable CONFIG_DEVPTS_MULTIPLE_INSTANCES

* Mon Apr 25 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-11
- update to unionfs to 2.5.8
- add patch6031 to fix open+unlink+ftruncate crash
  http://www.fsl.cs.sunysb.edu/pipermail/unionfs/2011-March/006091.html

* Wed Apr 13 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-10
- disable drm update patches
- update x86 config
  - disable CONFIG_KEXEC, CONFIG_RELOCATABLE

* Tue Apr 12 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-9
- update to 2.6.35.12
- update x86 configs
  - enable CONFIG_FTRACE, CONFIG_DYNAMIC_TRACE
- add drm update patches

* Tue Mar 08 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-8
- update to 2.6.35.11

* Sun Jan 09 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.35-7
- updated to 2.6.35.10

* Mon Sep 27 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-6
- update to 2.6.35.6
  - remove patch2600 which is merged in upstream

* Mon Sep 27 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-5
- add patch2600 to fix i915 modesetting failure on intel 8xx (<BTS:1039>)
- add BR: xz-lzma-compat, net-tools (<BTS:1038>)
- update unionfs to 2.5.6
- update tuxonice to 3.2-rc2

* Tue Sep 21 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-4
- update to 2.6.35.5

* Fri Sep 03 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-3
- update to 2.6.35.4

* Sat Aug 21 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-2
- update to 2.6.35.3

* Mon Aug 16 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.35-1
- update to 2.6.35.2
- update configs
- update unionfs to 2.5.5
- update tuxonice to 3.1.1.1

* Wed May 19 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.34-1
- update to 2.6.34
- patch1850: do not show fbcon logo on quiet mode
- patch1860: silence acpi blacklist code
- update tuxonice to git snapshot

* Fri May 14 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.33-5
- update to 2.6.33.4

* Tue Apr 06 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.33-4
- update to 2.6.33.2
- change configs
  - revert PREEMPT/PREEMPT_VOLUNTARY changes of previous kernel

* Wed Mar 24 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.33-3
- change configs
  - enable CONFIG_PREEMPT, disable CONFIG_PREEMPT_VOLUNTARY
- update unionfs to 2.5.4

* Tue Mar 15 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.33-2
- update to 2.6.33.1
- remove bootsplash patch, we use plymouth
- change CONFIG_VGASTATE to y
- add patch1394 to support PLANEX GW-US54GXS (Wishes:229)
- update tuxonice to 3.1-for-2.6.33

* Tue Mar 02 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.33-1
- update to 2.6.33
- update tuxonice to 3.0.99.48
- drop e1000 patch
- drop drm patches

* Sat Feb 20 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-14
- add Patch2833 for drm-intel
  - do not change DRM configuration when releasing load detect pipe

* Sat Feb 20 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-13
- add Patch2831,2832 for drm-intel

* Wed Feb 17 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-12
- Requires(pre): mkinitrd >= 6.0.93
  - new sysfs layout needs new mkinitrd
- add Patch2822 for drm-intel

* Mon Feb 15 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-11
- update to 2.6.32.8
- disable SYSFS_DEPRECATED

* Tue Feb 09 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-10
- update to 2.6.32.7
- enable NUMA support on x86_64

* Mon Feb  8 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.32-9
- drop Patch380 (see the changelog on 2.6.26-3 below)
- s/^BuildPreReq/BuildRequires/, s/^Prereq/Requires(pre)/

* Sun Feb 07 2010 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.32-8
- rebuilt with gcc 4.4.3

* Tue Jan 19 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-7
- update to 2.6.32.4

* Sat Jan 16 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-6
- update to 2.6.32.3
- update tuxonice to 2.0.99.44
- drop i586 support
  - build kernel-headers on i686

* Thu Dec 17 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-5
- update tuxonice to 3.0.99.41-for-2.6.32

* Tue Dec 15 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.32-4
- fix ppc.config

* Tue Dec 15 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-3
- update to 2.6.32.1
- add drm related patches
  Patch2811: drm-radeon-fixes.patch
  Patch2812: drm-radeon-dp-support.patch
  Patch2814: drm-nouveau.patch
  Patch2819: drm-intel-big-hammer.patch
  Patch2826: drm-i915-fix-sync-to-vbl-when-vga-is-off.patch
  Patch2827: linux-2.6-intel-agp-clear-gtt.patch
  Patch2830: linux-2.6.32-drm-i915-gem-on-pae.patch

* Sat Dec 05 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-2
- update x86 configs

* Fri Dec 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.32-1
- update to 2.6.32
- drop obsolete/upstream patches

* Tue Oct 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-8
- update to 2.6.31.3
- update x86 configs
  - set CONFIG_BLK_DEV_{SD,SR,SG} to "y"

* Thu Oct  8 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.31-7
- fix ppc config (RTC_DRV_PPC -> RTC_DRV_GENERIC etc.)

* Wed Oct  7 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.31-6
- add Patch360 (powerpc: Remove SMP warning from PowerMac cpufreq)

* Sat Sep 26 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-5
- update to 2.6.31.1
- prefer ata_piix driver on ICH4+ chipset instead of IDE/piix

* Mon Sep 21 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-4
- fix asm headers

* Mon Sep 21 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-3
- add missing headers to kernel-devel

* Sun Sep 20 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-2
- update x86/x86_64 configs
  - set CONFIG_{ATA,ATA_PIIX,SATA_AHCI} to "y"
- TODO: fix ppc config

* Sun Sep 20 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.31-1
- update to 2.6.31
- drop obsolete/upstream patches
- update tuxonice to current-20090911-v1
- update unionfs-2.5.2

* Sat Aug 15 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-43
- add patch20000 for fix CVE-2009-2692 (SOCKOPS_WRAP()) from fc10

* Thu Aug  6 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-42
- update to 2.6.27.29 with security fixes 

* Fri Jul 24 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-41
- update to 2.6.27.27
- add patch4012 to load panasonic-laptop automatically
  (<BTS:0734>, [VineSeed:17786], http://patchwork.kernel.org/patch/2275/)

* Fri Jul  3 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-40
- update to 2.6.27.26
- add patch810 for fix slub bug
- drop patch20000 (included in .26)

* Thu Jul  2 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-39
- change Provides alsa-driver 1.0.19 -> 1.0.17 

* Thu Jul  2 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-38
- drop patch8000,8001 (alsa driver are provided by alsa-driver package)

* Mon Jun 29 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-37
- 2.6.27.25
- drop patch280 (included in .25)
- add patch20000 for fix CVE-2009-1389 (r8169 driver)

* Sat Jun 06 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-36
- add Patch280: workaround failures on intel atom
- add Patch140[45]: fix e1000e driver
- add Patch2100: fix pata_sch, notice attached slave devices
- add Patch2900: update synaptics driver
- add Patch291[012]: update toshiba acpi driver
- add Patch2920: update eeepc laptop driver
- add Patch3000: fix up v4l2 video_open function

* Wed Jun 03 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-35
- fix x86_64 config

* Sun May 31 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-34
- enable CONFIG_PCI_MSI
- add Patch1840 to disable PCI MSI by default

* Sun May 24 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-33
- update to 2.6.27.24
- add Patch4011 to update panasonic-laptop

* Sun May 17 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.27-32
- now ppc kernel (vmlinux) is named as vmlinuz
  (still keep vmlinux* symlinks for compatibility though)
- remove MOL-related files and patches completely

* Sat May 16 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-31
- revert config change
  - re-enable CONFIG_SYSFS_DEPRECATED which is still needed by some
    userland utilities

* Thu May 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-30
- update configs
  - disable CONFIG_SYSFS_DEPRECATED

* Tue May 12 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-29
- update /boot/vmlinuz* symlink policy
  - vmlinuz -> newly installed kernel
  - vmlinuz-pae -> newly installed pae kernel
  - vmlinuz.old -> current running kernel

* Mon May 11 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-28
- add Patch2812 to add missing drm definitions

* Sun May 10 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-27
- update to 2.6.27.23

* Tue May 05 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-26
- apply patch2811 (again) to disable GEM on PAE or 8xx

* Tue May 05 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-25
- patch2813 - patch2819 are disabled to fix radeon dri issue

* Mon May 04 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.27-24.1
- test package to fix DRI issue on radeon

* Mon Apr 27 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.27-24
- modify post script for ppc (delete snd-powermac aliasing in modprobe.conf*)

* Mon Apr 27 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.27-23
- Patch6030 (unionfs) updated to 2.5.1

* Mon Apr 27 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.27-22
- update ppc.config (change CONFIG_RTC_DRV_PPC from m to y, and many more)
- s/modutils/module-init-tools/ in BuildPreReq

* Sat Apr 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-21
- change config options for tuxonice-3.0.1
  set following options to 'y'
  - CONFIG_CRYPTO_DEFLATE,CONFIG_CRYPTO_LZO
  - CONFIG_LZO_COMPRESS,CONFIG_LZO_DECOMPRESS
    
* Sun Apr 19 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-20
- update drm patches
- update configs
  - CONFIG_USB_OHCI_HCD_SSB change to n
- update tuxonice to 3.0.1-for-2.6.27

* Sat Mar 28 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-19
- update to 2.6.27.21
- update tuxonice to new current snapshot (20090313-v1)
- update kernel_prereq
  - mkinitrd >= 5.1.19.6
  - module-init-tools >= 3.6

* Wed Mar 18 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-18
- update to 2.6.27.20
- add PAE kernel entry to grub menu.lst
  - create /boot/vmlinuz-pae for latest pae kernel

* Wed Mar 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-17
- update to 2.6.27.19
- remove r1000 driver

* Wed Mar  4 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-16
- update tuxonice to current snapshot (20090214-v1)

* Thu Feb 19 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-15
- update Patch8001

* Wed Feb 18 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-14
- add Patch8000 and Patch8001 (update alsa-driver to 1.0.19)

* Fri Feb 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-13
- update to 2.6.27.17

* Fri Feb 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-12
- update to 2.6.27.16
- re-add Patch1450 to support smarter relatime
- modify kernel config
  - CONFIG_RT_GROUP_SCHED=y
  - CONFIG_CGROUP_SCHED=y
  - CONFIG_USER_NS=y
  - CONFIG_PID_NS=y
  - CONFIG_DEFAULT_RELATIME=y

* Sun Jan 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-11
- update to 2.6.27.13
- update drm-next.patch
  - drm-next.patch: drm/intel: fix VT switch issue harder.
- update drm-modesetting-radeon.patch
  - radeon drm: fix broken caching bits in radeon which broke AGP
- update to squashfs 3.4

* Mon Jan 19 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-10
- update to 2.6.27.12
- drop upstream patch (patch2500)

* Tue Jan 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-9
- add kernel-pae subpackage for PAE capable kernel (i686 only)

* Sat Dec 27 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.27-8
- add Patch1400 to support ich9 e1000 support
- add Patch140[123] to support newer e1000e device
- add Patch1410 to update r8169
- add Patch250[0124] to update wireless bits
- add Patch260[012] to update uvcvideo
- add Patch2800,281[0356] to update drm
- add Patch4000 to add atl2 driver
- add Patch4010 to add panasonic laptop extras

* Fri Dec 26 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-7
- fix header installation section (introducing asmarch macro etc.)
  especially for arch/powerpc/include/asm instead of include/asm-powerpc
  (see git commit b8b572e1015f81b4e748417be2629dfe51ab99f9)

* Mon Dec 22 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-6
- fix broken ppc.config (maybe at 2.6.27-4 or -5?)

* Sun Dec 21 2008 Daisuke SUZUKI <daisuke@linux.or.jp> - 2.6.27-5
- update to 2.6.27.10
- change configs
  - set CONFIG_RTC_DRV_CMOS=y
  - set CONFIG_TIO_IGNORE_LATE_INITCALL=y

* Wed Dec 17 2008 Daisuke SUZUKI <daisuke@linux.or.jp> - 2.6.27-4
- update to 2.6.27.9
- change configs
  - set CONFIG_RTC_CLASS=y instead of "m"
  - set CONFIG_CGROUPS=y

* Sat Dec 13 2008 Daisuke SUZUKI <daisuke@linux.or.jp> - 2.6.27-3
- add Conflicts: libdrm-devel < 2.4.0-4 to kernel-headers
- add kernel-firmware subpackage

* Fri Dec 12 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.27-2
- minor treatment for creating asm symlinks

* Thu Dec 11 2008 Daisuke SUZUKI <daisuke@linux.or.jp> - 2.6.27-1
- update to 2.6.27.8
- update tuxonice to current snapshot
- update unionfs to 2.5
- update configs

* Sun Oct 05 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.26-9
- Requires(post): mkinitrd >= 4.2.1.10-2vl5

* Mon Sep 15 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.26-8
- the first line "# powerpc" was missing on ppc.config of 2.6.26-7 - fixed.

* Tue Sep 09 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.26-7
- update to 2.6.26.5
- drop patch2230 (merged in upstream)

* Sat Aug 16 2008 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.26-6
- add patch2230 to fix it821x in pass-through mode segfaults
  (Already this patch is merged into kernel main tree)

* Mon Aug 11 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.26-5
- update to 2.6.26.2

* Wed Jul 23 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.26-4
- set CONFIG_X86_PAT to n
  - this may cause lock or boot problem in some system
- set CONFIG_IDE_GENERIC to n
  - disable ide_generic to fix piix dma problem.
    ide_generic does not help in recent PCs, and may cause confusion,
    so it should be set 'n' now.

* Wed Jul 22 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.26-3
- drop unneccesary powerpc patches
- re-create Patch370 and ppc.config
- add Patch380 and apply in reverse (until Vine goes to gcc-4.4.x)

* Tue Jul 22 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.26-2
- do not override asm-powerpc/highmem.h with asm-ppc/highmem.h anymore

* Sat Jul 19 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.26-1
- update to 2.6.26
- update configs
- drop unneeded patches
- update tuxonice from tuxonice-2.6.26.git

* Thu Jul 03 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-12
- update to 2.6.25.10
- fix CONFIG_NLS_DEFAULT to utf8

* Sat Jun 28 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-11
- update to 2.6.25.9
- add Patch2500 to implement smarter atime update support ([VineSeed:15756])
- change CONFIG_NLS_DEFAULT from euc-jp to utf-8

* Tue Jun 10 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.25-10
- updated to 2.6.25.6

* Mon Jun 09 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.25-9
- CONFIG_BLK_DEV_{IDECD,PIIX}=m to avoid piix driver to override
  ata_piix driver under ICH* PATA chipsets

* Sat May 31 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.25-8
- add Patch2400 to support Intel 965G/965GM chipsets
  (0e170c72c0c55bd78213a0f5053bd9a1dde403b7)

* Thu May 29 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.6.25-7
- add Patch2220 to fix boot suspending on recent MacBooks w/o AC adapter
  (see http://www.spinics.net/lists/linux-ide/msg23442.html and its thread)

* Sat May 17 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-6
- update to 2.6.25.4
- drop Patch2400 (already in upstream)

* Fri May 16 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.25-5
- fix ppc.config

* Thu May 15 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.25-4
- add Patch2400 (cb6716c879ecf49e2af344926c6a476821812061)
  to fix broken drive detection on some MacBooks
- disable Patch381 (no need to export copy_page symbols anymore)

* Fri May 02 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-3
- update to 2.6.25.1

* Mon Apr 28 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-2
- update unionfs to 2.3.3
- update tuxonice to 3.0-rc7

* Wed Apr 23 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.25-1
- update to 2.6.25
- update unionfs to 2.3.2
- update configs

* Sun Apr 06 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.24-7
- build x86 headers on i586 build

* Fri Apr 04 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.24-6
- re-introduce kernel-headers subpackage again
  (which obsoletes pretty old glibc-kernheaders package)

* Sun Mar 30 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.24-5
- fix ppc.config
- add buildmol (default 0)

* Thu Mar 27 2008 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.24-4
- fix include file install section for x86_64

* Wed Mar 26 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.24-3
- drop supermount-ng patch
- add Patch6020 for bootsplash

* Tue Mar 25 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.24-2
- update to 2.6.24.4

* Mon Mar 24 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.24-1
- update to 2.6.24.3
- update unionfs to 2.2.4
- update x86/x86_64 configs

* Fri Jan 25 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl7
- update TuxOnIce to 3.0-rc5-2.6.23.14

* Mon Jan 21 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl6
- updated to 2.6.23.14
- update TuxOnIce to 3.0-rc4-2.6.23.14

* Sun Dec 16 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.23-0vl5
- add Patch381 (unionfs won't build without this patch)
- rename mol-kmods to kernel-module-mol

* Sat Dec 15 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl4
- updated to 2.6.23.11
- update TuxOnIce to 3.0-rc3-2.6.23.9
- update unionfs to 2.1.11
- update squashfs to 3.3

* Wed Dec  5 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.23-0vl3
- updated to 2.6.23.9

* Sun Nov 18 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl2
- update TuxOnIce to 3.0-rc2-2.6.23.1
- update ppc config

* Sat Nov 17 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl1
- update to 2.6.23.8

* Mon Nov 05 2007 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.23-0vl0.7
- update x86_64.config

* Tue Oct 30 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl0.6
- update x86 config

* Mon Oct 29 2007 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.23-0vl0.5
- update x86_64.config
- add patch2301 for fix a bug in the LSI emulation in VMWare 5

* Mon Oct 22 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.23-0vl0.4
- unionfs updated to 2.1.7

* Mon Oct 22 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.23-0vl0.3
- add Patch380 to fix symbol errors with mol-kmods
- fix ppc.config (CONFIG_SLUB_DEBUG{,_ON} were missing)

* Sun Oct 21 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl0.2
- require mkinitrd >= 4.2.1.8-0vl5 for tuxonice-3.0
- update grub/menu.lst to use "resume=" parameter instead of "resume2="

* Sun Oct 21 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.23-0vl0.1
- update x86 config
- update ppc config (enable SLUB allocator instead of SLAB allocator)

* Fri Oct 19 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.23-0vl0
- initial attempt for upgrading 2.6.23
- 2.6.23.1
- drop many "untested" or "already in upstream" patches
- add e1000e driver
- r1000 updated to 1.0.7 (with a patch to fix compile failure)
- drop fbsplash
- updated other components such as following:
  - TuxOnIce (formerly suspend2) 3.0-rc1
  - supermount-ng 2.2.2
  - unionfs 2.1.6
  - squashfs 3.2r2
  - Mac-On-Linux 0.9.72.1 (only on ppc)
- other important TODOs:
  - prepare correctly working i?86/x86_64 configs for the first thing!
  - clean up many sections in this spec file
  - re-organize many of the patches
  - include another kind of splash mechanism (usplash? splashy? etc.)
  - time to consider introducing xen and SELinux?

* Thu Oct 04 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl89
- re-update patch1050,1060 for suspend2 2.2.8 on x86_64
- update patch1390 to 3.71b (wishes:128)
- update patch1630 (tg3 section is no needed)

* Wed Oct 03 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl88
- Prereq: mkinitrd >= 4.2.1.8-0vl2 for new suspend2

* Sun Sep 30 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl87
- update suspend2 patch to 2.2.8-for-2.6.16.21

* Fri Sep 28 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl86
- add patch20390 for fix CVE-2007-4573 (Zero extend all registers)

* Thu Sep 27 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl85
- add patch20370 for fix CVE-2007-3739 ("mm/mmap.c")
- add patch20380 for fix CVE-2007-3740 (CIFS should honor umask)
- update Source200, patch1050,1060 for fix function name conflict on x86_64

* Mon Aug 27 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl84
- fix following configs for ppc
  - CONFIG_IEEE1394_EXPORT_FULL_API=y
  - CONFIG_IEEE1394_OHCI1394=m

* Mon Aug 27 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl83
- add Patc2146 for libata/ahci to add new chipset(sb700,mcp7x,via) support
- update Patch2143

* Sun Aug 26 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl82
- update Patch2143

* Sun Aug 26 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl81
- add Patch2140 for libata ich9 support
- add Patch2141 for generic ahci class support
- add Patch2142 for libata/ide mcp67 support
- add Patch2143 for libata/ata_piix update to fix port mapping problem in ich8
- add Patch2144 for libata/ahci update to force SB600 as AHCI mode
- add Patch2145 for libata/sata_via to add new chipset support
- add Patch2220 for IDE/atiixp SB600 support
- add Patch3200 for agpgart/intel-agp intel 965 support
- add Patch3210 for drm/i915 intel 945gme support
- add Patch3010 for hda_intel ICH9/RS690/MCP6x support

* Sat Aug 25 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl80
- add patch20360 for fix CVE-2007-3848 (PR_SET_PDEATHSIG)
- add patch20350 for fix CVE-2007-4308 (aac raid driver)
- add Patch20320 for fix CVE-2007-3513 (usblcd)
- add Patch20330 for fix CVE-2007-1353 (Bluetooth Fix L2CAP/HCI setsockopt())
- add Patch20340 for fix CVE-2007-3105 (random)
- add patch20310 for fox CVE-2006-7203(compat_sys_mount())
- add patch1371 for support Corega LAPCIGT NIC (R8169)
- renumber patch1371 -> patch1375 (linux-2.6.16-r1000-1.0.4.patch)

* Sun Jun 10 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl79
- add patch20280 for fix CVE-2007-2453
- add patch20290 for fix CVE-2007-2875
- add patch20300 for fix CVE-2007-2876
- add Patch2300 to update 3w-9xxx driver (from 3ware)

* Sat Jun 09 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl78
- add Patch1391 to update forcedeth-0.60

* Thu May 31 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl77
- for VineSeed

* Mon May 28 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl76
- add patch20250 for fix CVE-2007-1861 (NETLINK_FIB_LOOKUP)
- add patch20260 for fix CVE-2007-2172 (anout-of-bounds access)
- add patch20270 for fix CVE-2007-2525 (PPP Over X/Ethernet)

* Sat Apr 14 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl75
- add patch20225 for fix CVE-2007-1497 (ipv6_conntrack_in())
- add patch20240 for fix CVE-2007-1357 (atalk_sum_skb() in AppleTalk)
- fix changelog typo

* Fri Apr 06 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl74
- add patch20200 for fix CVE-2007-1217 (isdn capi)
- update config (CONFIG_CAPI_TRACE is added)
- add patch20220 for fix CVE-2007-1496 (nf_conntrack in netfilter)
- add patch20230 for fix CVE-2007-1592 (cp_v6_syn_recv_soc())
- remake patch20180 (for CVE-2007-1000)
  - old patch included CVE-2007-1388 fix
- add patch20210 for fix CVE-2007-1388 (do_ipv6_setsockopt())
  - it was separated from old patch20180

* Wed Mar 14 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl73
- add patch20190 for fix CVE-2007-0958 (PT_INTERP)

* Wed Mar 14 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl72
- add patch for fix CVE-2007-0005 (cm4040)
- add patch for fix CVE-2007-1000 (ipv6_getsockopt_sticky())

* Wed Feb 21 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl71
- add patch20160 for fix CVE-2007-0772 (NFSACL DoS)

* Thu Feb 15 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl70
- add patch20150 for fix CVE-2007-0006 ("key_alloc_serial()" DoS)

* Mon Feb 05 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl69
- add patch20140 for fix CVE-2006-5753 (listxattr Memory Corruption)

* Thu Jan 18 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl68
- add patch20120 for fix CVE-2006-4814 (mincore User Space Access Lock issue)
- add patch20130 for fix CVE-2006-5749 (ISDN init_timer)

* Mon Jan 08 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl67
- rebuilt

* Mon Dec 25 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl66.1
- test package
- add patch20070 for fix CVE-2006-5173
- add patch20080 for fix CVE-2006-5823
- add patch20090 for fix CVE-2006-6053
- add patch20100 for fix CVE-2006-6054
- add patch20110 for fix CVE-2006-6056

* Wed Dec 20 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl66
- add patch20060 for fix CVE-2006-6106

* Fri Dec 15 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl65
- update to 2.6.16.36

* Sun Dec 10 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl64
- drop Patch2220.

* Thu Dec 07 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl63
- update to 2.6.16.34
- drop patch1380,2300,200[01234]0 which are merged in 2.6.16.34

* Thu Dec 07 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl62
- update tg3 driver to 3.66d (Patch1390)
- update ix86 config
  - set CONFIG_ACPI_BLACKLIST_YEAR to 1999 instead of 2001

* Sun Dec 03 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl61
- add Patch2130 to use ACHI on libata suspend/resume.
- add Patch2220 to support DMA on ICH6M (<BTS:407>)
  http://marc.theaimsgroup.com/?l=linux-ide&m=114317385718285&w=2

* Sun Nov 26 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.6.16-0vl60.1
- add patch20000 for fix CVE-2006-4997
- add patch20010 for fix CVE-2006-4572
- add patch20020 for fix CVE-2006-4623
- add patch20030 for fix CVE-2005-4352
- add patch20040 for fix CVE-2006-5619
- add patch20050 for fix CVE-2006-5757
- add patch1361 for fix e1000 suspend/resume powerup and irq allocation
- add patch1380 for support sis900 new PHY
- add patch2300 for fix pppoe

* Fri Oct 27 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl60
- add Patch1344 to fix sky2 88E803X transmit lokup problem (<BTS:309>)
  http://marc.theaimsgroup.com/?l=git-commits-head&m=116146456420139&w=2

* Tue Oct 24 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl59
- [ppc] drop Patch351, and add/modify Patch352, Patch353 and Patch354
        for better offb/BootX fixes, taken from linux-2.6 git tree
  - Patch352: ab13446616118dc61c00ea50cc49919400717dd0 (v2.6.18-rc1)
  - Patch353: 98c82472e98469ef23d7c680a0d6be1429540166 (v2.6.18-rc3)
  - Patch354: 6cdd2bdfb9e2449f1c8a0f729cdf9cfd733dd63f (v2.6.18-rc5)
- [ppc] add Patch355 (eMac lockup fix)
  - Patch355: 5a47d749e3d067e057d276075fed1d91749d3841 (v2.6.17-rc6)

* Fri Oct 20 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl58
- add Patch6025 (ad-hoc unicon revert patch for ppc)
- add mol-kmods subpackage (which needs fully-built kernel source to compile)
- fix %%post section (for snd-powermac and vmlinu[xz] symlinks)

* Thu Oct 19 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl57
- add Patch1371 for r1000 driver 1.0.4

* Tue Oct 17 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl56
- update x86 config
  - enable more drivers
  - disable cpufreq-nforce2

* Sun Oct 15 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl55
- update sdhci driver to 0.12

* Sun Oct 15 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl54
- add sdhci driver 0.11 (from mm patch)

* Sat Oct 14 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl53
- add bcm43xx driver backported from 2.6.17
- fix typo in %%post
- update x86 config

* Fri Oct 06 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl52
- replace Patch1880
  - Patch inserts PCI memory mapped config region(s) into the resource map. This
    will allow for the MMCCONFIG regions to be marked as busy in the iomem
    address space as well as the regions(s) showing up in /proc/iomem.
    (backported from 2.6.19-rc)

* Thu Oct 05 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl51
- add Patch1880 (<BTS:218>)
  - Disable MMCONFIG on Intel SDV using DMI blacklist
    (see http://www.x86-64.org/lists/patches/msg03704.html)
- add Patch2210 to suuport Marvell PATA controller by generic ide driver.
- use vmlinux symlink on ppc architecture

* Thu Oct 05 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl50
- add ivtv driver fix (Thanks to T.Adachi)

* Sun Oct 01 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl49
- update unicon patch (<BTS:196>)
- fix %%post to correct modprobe.conf.dist path.

* Tue Sep 26 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl48
- update ivtv driver to fix bug (Thanks to T.Adachi)

* Mon Sep 25 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl47
- update unicon patch to fix broken double byte chars with gpm.
  - XXX: still broken on selecting strings with gpm.
  - We are not supporting gpm any longer, do not expect any
    fix for this.

* Sat Sep 23 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl46
- add Patch3100 to use mutexes in firmware_class

* Fri Sep 22 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl45
- update to 2.6.16.29

* Thu Sep 21 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl44
- add Patch2120 to add vt8237a support for sata_via
- update Patch2110 to add SiS ahci controller's pciid
- add more Japanese summaries.

* Wed Sep 20 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl43
- change Group of kernel-doc to Applications/Documentation

* Sun Sep 17 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl42
- add Patch352 to fix boot with ramdisk from BootX on OldWorld PowerMac
  (patch derived from BenH, then appeared on Ubuntu Malone #50746)

* Sun Sep 17 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl41
- disable CONFIG_SND_AOA* on ppc.config (use snd-powermac instead)

* Sun Sep 17 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl40
- add Patch1343 to fix sky2 "phy read timeout" message flood.
  (<BTS:189>)

* Sun Sep 17 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl39
- update sky2 to 1.7 (<BTS:189>)
- renumber sky2/skge patches

* Sat Sep 16 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl38
- add Patch1370 to update r8169 driver
  - add support RTL8168*/RTL810x 

* Mon Sep 11 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl37
- add Patch2200 to support JMicron JMB36x ATA controllers
  by legacy IDE driver
- update configs

* Sun Sep 10 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl36
- update Patch6000 to fix unicon
  (FIXME: bootsplash does not support unicon)
- add Patch2110 to add newer chipset support for AHCI
  (JMicron, ATI, NVIDIA)
    
* Sat Sep 09 2006 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.16-0vl35
- update x86_64.config (CONFIG_SND_VXPOCKET is not set)

* Fri Sep 08 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl34
- add Patch351 for offb on unsupported cards

* Fri Sep 08 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl33
- fix ppc.config (CONFIG_FB_RIVA is not set, disable unneeded snd modulers)
- fix Patch3000 (no changes under ppc/ directory - it's broken)

* Tue Sep 05 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl32
- update e1000 driver to 7.2.7
- update configs

* Mon Sep 04 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl31
- update alsa-driver to 1.0.12
- update e1000 driver to 7.1.9-k4 (from 2.6.18-rc5) (<BTS:0136>)
- add patch10000 to remove localized version string from /proc/version
  (<BTS:0126>)
- update unionfs to 1.2 (<BTS:0131>)

* Sun Sep 03 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl30
- fix ppc.config (CONFIG_XMON etc)

* Thu Aug 31 2006 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.16-0vl29
- update x86_64.config

* Tue Aug 29 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl28
- update to 2.6.16.28

* Fri Aug 25 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl27
- fix more of ppc.config (CONFIG_MD etc)

* Wed Aug 23 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl26
- add Patch1350,1351 for sky2 update
  - sky2-1.5, sky2 jumbo paket fix
- add Patch1352 for skge update
- add Patch2100 to add support Promise 2037x SATA controllers with PATA ports

* Thu Aug 10 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl25
- update x86.config, re-create i586.config from i686.config
- add Patch1850 from FC (add nosoftlock runtime option)

* Wed Jul 26 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl24
- add Patch1203 to fix nfsd crash.

* Tue Jul 25 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl23
- update to 2.6.16.27

* Thu Jul 20 2006 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.16-0vl22
- update x86_64.config

* Tue Jul 18 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl21
- update to 2.6.16.26

* Fri Jul 14 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl20
- update to 2.6.16.24

* Sun Jul 02 2006 NAKAMURA Kenta <kenta@vinelinux.org> 2.6.16-0vl19
- update x86_64.config, add CONFIG_HPET_EMULATE_RTC=y
  (see [VineSeed-x86_64:00146] from s.mishima)

* Wed Jun 28 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl18
- modify Patch3000 for ppc
- disable swsusp on ppc again
- update ppc.config

* Wed Jun 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl17
- update to 2.6.16.22
- disable buildsmp, default normal kernel supports smp now.

* Tue Jun 13 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl16
- update to 2.6.16.20

* Sun May 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl15
- update to 2.6.16.18
- update squashfs to 3.0

* Sun May 21 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl14
- update to 2.6.16.17

* Tue May 16 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl13
- add Patch3000 to update alsa driver from 2.6.17-rc4

* Tue May 16 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl12
- add saa7133gyc/ivtv driver from paken. (Patch7000)
  (Thanks for T.Adachi)
- update ix86 config
  add CONFIG_VIDEO_GR3DYCS=m, CONFIG_VIDEO_IVTV=m

* Sat May 13 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl11
- update to 2.6.16.16
- update ix86 config

* Wed May 03 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl10
- update to 2.6.16.13
- update software suspend2 to 2.2.5

* Wed Apr 26 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl9
- enable swsusp2 on ppc (for testing)

* Thu Apr 20 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl8
- update to 2.6.16.9

* Wed Apr 12 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl7
- update to 2.6.16.4
- update software suspend2 to 2.2.4

* Tue Mar 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl6
- update to 2.6.16.1
- update software suspend2 to 2.2.2.1

* Tue Mar 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl5
- XXX:temporarily back to suspend2-2.2.0.1, 2.2.1 does not work correctly.

* Tue Mar 21 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl4
- fix more of ppc configs

* Mon Mar 20 2006 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.16-0vl3
- update ppc configs

* Mon Mar 20 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl2
- update x86_64 configs

* Mon Mar 20 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.16-0vl1
- update to 2.6.16
- update ix86*, x86_64* configs
  regenerate smp configs from up config
- update software suspend2 to 2.2.1

* Sat Mar 04 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl7
- fix unicon driver
- update x86_64 configs (still need to work)
- TODO: ppc* configs

* Thu Mar 02 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl6
- add missing files to -devel package

* Wed Mar 01 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl5
- add symlinks for initrd/initrd.old

* Wed Mar 01 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl4
- add Patch6011 to fix supermount-ng
- add Patch6031 to fix unionfs

* Tue Feb 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl3
- update ix86* config
- drop some FC patches
  - debug optios, execshield

* Mon Feb 27 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl2
- update to 2.6.16-rc5
- update ix86* configs
- update software suspend2 to 2.2.0.1
- update unionfs to 1.1.3.20060221
- TODO: unicon driver should be fixed
- TODO: ppc* configs and x86_64* configs not fixed yet

* Sun Feb 05 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.15-0vl1
- update to 2.6.16-rc2
- update ix86* config
- update squashfs to 2.2-r2
- update software suspend2 to 2.2 (not applied yet)
- TODO: unicon driver should be fixed

* Mon Oct 24 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.14-0vl1
- upated to 2.6.14.3
- update ix86* config
- update software suspend to 2.2-rc13
- TODO: unicon driver should be fixed

* Thu Aug 18 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.14-0vl0
- based on 2.6.14-1.1636_FC4 (changelogs NOT merged yet)
- updated to 2.6.14.2
- Patch6000 (unicon) temporally disabled - TODO in top priority!
- updated Patch6030 (unionfs 1.1.1), with eliminating asm/segment.h inclusion
  (ppc* and sparc* don't have asm/segment.h - see ChangeLog-2.6.14)
- TODO: ix86* configs not fixed yet

* Thu Aug 18 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.12-0vl11
- added Patch313 for better fan control on recent PowerBooks
  (http://lists.debian.org/debian-powerpc/2005/08/msg00478.html)

* Thu Aug 18 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.12-0vl10
- added Patch1920
  (http://lists.debian.org/debian-powerpc/2005/01/msg00219.html)

* Thu Aug 18 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.12-0vl9
- some more fixes for ppc.config and ppc-smp.config (THERM_* to y)
- updated Patch6030 (unionfs 1.0.3)
- added Patch312 to supress CPU-temp messages from therm_windtunnel module

* Sun Aug 14 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.12-0vl7
- more fixes for ppc.config and ppc-smp.config

* Thu Jul 14 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.6.12-0vl6
- initial attempt for ppc archtecture (ppc64 not yet)

* Fri Jun 24 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.12-0vl5
- update to 2.6.12.1 (was not applied in 2.6.12-0vl4)
- add suquashfs-2.1-r2 (Patch6030)
- update configs
  - change to 'y' for BLK_DEV_LOOP, CRAMFS, SQUASHFS
  - set samba default codepage to cp932
  - set vfat default codepage to cp932, default iocharset to euc-jp
  - set NLS_DEFAULT to cp932 instead of utf-8

* Wed Jun 22 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.12-0vl4
- add requires: kernel-doc instead of kernel26-doc

* Tue Jun 21 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.12-0vl3
- rename kernel26 to kernel

* Mon Jun 20 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.12-0vl2
- update configs
  - enable CONFIG_INPUT_MOUSEDEV_PSAUX for compatibility

* Sat Jun 18 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.12-0vl1
- update to 2.6.12
- remove tux http accelerator

* Sat Jun 11 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl7
- fix saa7133gyc driver
- add Patch200 to add no_timer_check hack for i386 kernel.
  (thanks to NAKAMURA Kenta)
- update configs
  - enable IO_APIC in UP kernel.

* Fri Jun 10 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl6
- update to 2.6.12-rc6
- add software suspend 2.1.9 ( not applyed yet )
- add Patch6030 for unionfs-1.0.12a
- update configs

* Wed Jun 08 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl5
- add kernel-source package.

* Sun Jun 05 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl4
- fix and update bootsplash to 3.1.6
- add Patch6010 for supermount-ng-2.0.8

* Sun May 29 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl3
- add Patch6010 for bootsplash-3.1.4

* Sun May 29 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl2
- port unicon patch(Patch6000) from 2.6.9 ppc kernel.

* Sat May 28 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 2.6.11-0vl1
- initial build of kernel26 package for Vine Linux
  (partially based on FC kernel)
- update to kernel-2.6.12-rc5
- use Vine Logo for fb console.

* Tue May 24 2005 Dave Jones <davej@redhat.com>
- Update various cpufreq drivers.

* Mon May 23 2005 Dave Jones <davej@redhat.com>
- Add extra id to SATA Sil driver. (#155748)
- Fix oops on rmmod of lanai & ms558 drivers when no hardware present.

* Mon May 23 2005 Dave Jones <davej@redhat.com>
- Fix double unlock of spinlock on tulip. (#158522)

* Mon May 23 2005 David Woodhouse <dwmw2@redhat.com>
- audit updates: log serial # in user messages, escape comm= in syscalls

* Mon May 23 2005 Dave Jones <davej@redhat.com>
- 2.6.12-rc4-git6
  MMC update, reiserfs fixes, AIO fix.
- Fix absolute symlink in -devel (#158582)
- 2.6.12-rc4-git7
  PPC64 & i2c fixes
- Fix another divide by zero in ipw2100 (#158406)
- Fix dir ownership in kernel-doc rpm (#158478)

* Sun May 22 2005 Dave Jones <davej@redhat.com>
- Fix divide by zero in ipw2100 driver. (#158406)
- 2.6.12-rc4-git5
  More x86-64 updates, Further pktcdvd frobbing,
  yet more dvb updates, x86(64) ioremap fixes,
  ppc updates, IPMI sysfs support (reverted for now due to breakage),
  various SCSI fixes (aix7xxx, spi transport), vmalloc improvements

* Sat May 21 2005 David Woodhouse <dwmw2@redhat.com>
- Fix oops in avc_audit() (#158377)
- Include serial numbers in non-syscall audit messages

* Sat May 21 2005 Bill Nottingham <notting@redhat.com>
- bump ipw2200 conflict

* Sat May 21 2005 Dave Jones <davej@redhat.com> [2.6.11-1.1334_FC4]
- driver core: restore event order for device_add()

* Sat May 21 2005 David Woodhouse <dwmw2@redhat.com>
- More audit updates. Including a fix for AVC_USER messages.

* Fri May 20 2005 Dave Jones <davej@redhat.com>
- 2.6.12-rc4-git4
  networking fixes (netlink, pkt_sched, ipsec, netfilter,
  ip_vs, af_unix, ipv4/6, xfrm). TG3 driver improvements.

* Thu May 19 2005 Dave Jones <davej@redhat.com> [2.6.11-1.1327_FC4]
- 2.6.12-rc4-git3
  Further fixing to raw driver. More DVB updates,
  driver model updates, power management improvements,
  ext3 fixes.  
- Radeon on thinkpad backlight power-management goodness.
  (Peter Jones owes me two tacos).
- Fix ieee1394 smp init.

* Thu May 19 2005 Rik van Riel <riel@redhat.com>
- Xen: disable TLS warning (#156414)

* Thu May 19 2005 David Woodhouse <dwmw2@redhat.com>
- Update audit patches

* Thu May 19 2005 Dave Jones <davej@redhat.com> [2.6.11-1.1325_FC4]
- Fix up missing symbols in ipw2200 driver.
- Reenable debugfs / usbmon. SELinux seems to cope ok now.
  (Needs selinux-targeted-policy >= 1.23.16-1)

* Wed May 18 2005 Dave Jones <davej@redhat.com>
- Fix up some warnings in the IDE patches.
- 2.6.12-rc4-git2
  Further pktcdvd fixing, DVB update, Lots of x86-64 updates,
  ptrace fixes, ieee1394 changes, input layer tweaks,
  md layer fixes, PCI hotplug improvements, PCMCIA fixes,
  libata fixes, serial layer, usb core, usbnet, VM fixes,
  SELinux tweaks.
- Update ipw2100 driver to 1.1.0
- Update ipw2200 driver to 1.0.4 (#158073)

* Tue May 17 2005 Dave Jones <davej@redhat.com>
- 2.6.12-rc4-git1
  ARM, ioctl security fixes, mmc driver update,
  ibm_emac & tulip netdriver fixes, serial updates
  ELF loader security fix.

* Mon May 16 2005 Rik van Riel <riel@redhat.com>
- enable Xen again (not tested yet)
- fix a typo in the EXPORT_SYMBOL patch

* Sat May 14 2005 Dave Jones <davej@redhat.com>
- Update E1000 driver from netdev-2.6 tree. 
- Add some missing EXPORT_SYMBOLs.

* Fri May 13 2005 Dave Jones <davej@redhat.com>
- Bump maximum supported CPUs on x86-64 to 32.
- Tickle the NMI watchdog when we're doing serial writes.
- SCSI CAM geometry fix.
- Slab debug single-bit error improvement.

* Thu May 12 2005 David Woodhouse <dwmw2@redhat.com>
- Enable CONFIG_ISA on ppc32 to make the RS/6000 user happy.
- Update audit patches

* Wed May 11 2005 Dave Jones <davej@redhat.com>
- Add Ingo's patch to detect soft lockups.
- Thread exits silently via __RESTORE_ALL exception for iret. (#154369)

* Wed May 11 2005 David Woodhouse <dwmw2@redhat.com>
- Import post-rc4 audit fixes from git, including ppc syscall auditing

* Wed May 11 2005 Dave Jones <davej@redhat.com>
- Revert NMI watchdog changes.

* Tue May 10 2005 Dave Jones <davej@redhat.com>
- Enable PNP on x86-64

* Tue May 10 2005 Jeremy Katz <katzj@redhat.com>
- make other -devel packages provide kernel-devel so they get 
  installed instead of upgraded (#155988)

* Mon May  9 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.12-rc4
  | Xen builds are temporarily disabled again.
- Conflict if old version of ipw firmware is present.

* Fri May  6 2005 Dave Jones <davej@redhat.com>
- Add PCI ID for new sundance driver. (#156859)

* Thu May  5 2005 David Woodhouse <dwmw2@redhat.com>
- Import audit fixes from upstream

* Wed May  4 2005 Jeremy Katz <katzj@redhat.com>
- enable radeonfb and agp on ppc64 to fix X on the G5

* Tue May  3 2005 Dave Jones <davej@redhat.com>
- Disable usbmon/debugfs again for now until SELinux policy is fixed.

* Mon May  2 2005 David Woodhouse <dwmw2@redhat.com>
- Make kallsyms include platform-specific symbols
- Fix might_sleep warning in pbook clock-spreading fix

* Sun May  1 2005 Dave Jones <davej@redhat.com>
- Fix yesterdays IDE fixes.
- Blacklist another brainless SCSI scanner. (#155457)

* Sun May  1 2005 David Woodhouse <dwmw2@redhat.com>
- Fix EHCI port power switching

* Sun May  1 2005 Dave Jones <davej@redhat.com>
- Enable usbmon & debugfs. (#156489)

* Sat Apr 30 2005 Dave Jones <davej@redhat.com>
- Numerous IDE layer fixes from Alan Cox.
- Kill off some stupid messages from the input layer.

* Fri Apr 29 2005 Roland McGrath <roland@redhat.com>
- Fix the 32bit emulation on x86-64 segfaults.

* Wed Apr 27 2005 Dave Jones <davej@redhat.com>
- Hopefully fix the random reboots some folks saw on x86-64.

* Wed Apr 27 2005 Jeremy Katz <katzj@redhat.com>
- fix prereqs for -devel packages

* Wed Apr 27 2005 Rik van Riel <riel@redhat.com>
- Fix up the vdso stuff so kernel-xen* compile again
- Import upstream bugfix so xenU domains can be started again

* Tue Apr 26 2005 Dave Jones <davej@redhat.com>
- Fix up the vdso again, which broke on the last rebase to -rc3
- Fix the put_user() fix. (#155999)

* Mon Apr 25 2005 Dave Jones <davej@redhat.com>
- Fix x86-64 put_user()
- Fix serio oops.
- Fix ipv6_skip_exthdr() invocation causing OOPS.
- Fix up some permissions on some /proc files.
- Support PATA drives on Promise SATA. (#147303)

* Mon Apr 25 2005 Rik van Riel <riel@redhat.com>
- upgrade to the latest version of xenolinux patches
- reenable xen (it boots, ship it!)

* Sat Apr 23 2005 David Woodhouse <dwmw2@redhat.com>
- Enable adt746x and windtunnel thermal modules
- Disable clock spreading on certain pbooks before sleep
- Sound support for Mac Mini

* Fri Apr 22 2005 Dave Jones <davej@redhat.com>
- Reenable i2c-viapro on x86-64.

* Fri Apr 22 2005 Dave Jones <davej@redhat.com>
- Don't build powernow-k6 on anything other than 586 kernels.
- Temporarily disable Xen again.

* Wed Apr 20 2005 Dave Jones <davej@redhat.com>
- 2.6.12rc3

* Wed Apr 20 2005 Dave Jones <davej@redhat.com>
- Adjust struct dentry 'padding' based on 64bit'ness.

* Tue Apr 19 2005 Dave Jones <davej@redhat.com>
- Print stack trace when we panic.
  Might give more clues for some of the wierd panics being seen right now.
- Blacklist another 'No C2/C3 states' Thinkpad R40e BIOS. (#155236)

* Mon Apr 18 2005 Dave Jones <davej@redhat.com>
- Make ISDN ICN driver not oops when probed with no hardware present.
- Add missing MODULE_LICENSE to mac_modes.ko

* Sat Apr 16 2005 Dave Jones <davej@redhat.com>
- Make some i2c drivers arch dependant.
- Make multimedia buttons on Dell inspiron 8200 work. (#126148)
- Add diffutils buildreq (#155121)

* Thu Apr 14 2005 Dave Jones <davej@redhat.com>
- Build DRM modular. (#154769)

* Wed Apr 13 2005 Rik van Riel <riel@redhat.com>
- fix up Xen for 2.6.12-rc2
- drop arch/xen/i386/signal.c, thanks to Roland's vdso patch (yay!)
- reenable xen compile - this kernel test boots on my system

* Tue Apr 12 2005 Dave Jones <davej@redhat.com>
- Further vdso work from Roland.

* Mon Apr 11 2005 David Woodhouse <dwmw2@redhat.com>
- Disable PPC cpufreq/sleep patches which make sleep less reliable
- Add TIMEOUT to hotplug environment when requesting firmware (#153993)

* Sun Apr 10 2005 Dave Jones <davej@redhat.com>
- Integrate Roland McGrath's changes to make exec-shield
  and vdso play nicely together.

* Fri Apr  8 2005 Dave Jones <davej@redhat.com>
- Disable Longhaul driver (again).

* Wed Apr  6 2005 Dave Jones <davej@redhat.com>
- 2.6.12rc2
  - netdump/netconsole currently broken.
  - Xen temporarily disabled.

* Fri Apr  1 2005 Dave Jones <davej@redhat.com>
- Make the CFQ elevator the default again.

* Thu Mar 31 2005 Rik van Riel <riel@redhat.com>
- upgrade to new upstream Xen code, twice 
- for performance reasons, disable CONFIG_DEBUG_PAGEALLOC for FC4t2

* Wed Mar 30 2005 Rik van Riel <riel@redhat.com>
- fix Xen kernel compilation (pci, page table, put_user, execshield, ...)
- reenable Xen kernel compilation

* Tue Mar 29 2005 Rik van Riel <riel@redhat.com>
- apply Xen patches again (they don't compile yet, though)
- Use uname in kernel-devel directories (#145914)
- add uname-based kernel-devel provisions (#152357)
- make sure /usr/share/doc/kernel-doc-%%{kversion} is owned by a
  package, so it will get removed again on uninstall/upgrade (#130667)

* Mon Mar 28 2005 Dave Jones <davej@redhat.com>
- Don't generate debuginfo files if %%_enable_debug_packages isnt set. (#152268)

* Sun Mar 27 2005 Dave Jones <davej@redhat.com>
- 2.6.12rc1-bk2
- Disable NVidia FB driver for time being, it isn't stable.

* Thu Mar 24 2005 Dave Jones <davej@redhat.com>
- rebuild

* Tue Mar 22 2005 Dave Jones <davej@redhat.com>
- Fix several instances of swapped arguments to memset()
- 2.6.12rc1-bk1

* Fri Mar 18 2005 Dave Jones <davej@redhat.com>
- kjournald release race. (#146344)
- 2.6.12rc1

* Thu Mar 17 2005 Rik van Riel <riel@redhat.com>
- upgrade to latest upstream Xen code

* Tue Mar 15 2005 Rik van Riel <riel@redhat.com>
- add Provides: headers for external kernel modules (#149249)
- move build & source symlinks from kernel-*-devel to kernel-* (#149210)
- fix xen0 and xenU devel %%post scripts to use /usr/src/kernels (#149210)

* Thu Mar 10 2005 Dave Jones <davej@redhat.com>
- Reenable advansys driver for x86

* Tue Mar  8 2005 Dave Jones <davej@redhat.com>
- Change SELinux execute-related permission checking. (#149819)

* Sun Mar  6 2005 Dave Jones <davej@redhat.com>
- Forward port some FC3 patches that got lost.

* Fri Mar  4 2005 Dave Jones <davej@redhat.com>
- Fix up ACPI vs keyboard controller problem.
- Fix up Altivec usage on PPC/PPC64.

* Fri Mar  4 2005 Dave Jones <davej@redhat.com>
- Finger the programs that try to read from /dev/mem.
- Improve spinlock debugging a little.

* Thu Mar  3 2005 Dave Jones <davej@redhat.com>
- Fix up the unresolved symbols problem.

* Thu Mar  3 2005 Rik van Riel <riel@redhat.com>
- upgrade to new Xen snapshot (requires new xen RPM, too)

* Wed Mar  2 2005 Dave Jones <davej@redhat.com>
- 2.6.11

* Tue Mar 1 2005 David Woodhouse <dwmw2@redhat.com>
- Building is nice. Booting would be better. Work around GCC -Os bug which
  which makes the PPC kernel die when extracting its initramfs. (#150020)
- Update include/linux/compiler-gcc+.h

* Tue Mar 1 2005 Dave Jones <davej@redhat.com>
- 802.11b/ipw2100/ipw2200 update.
- 2.6.11-rc5-bk4

* Tue Mar 1 2005 David Woodhouse <dwmw2@redhat.com>
- Fix ppc/ppc64/ppc64iseries builds for gcc 4.0
- Fix Xen build too

* Mon Feb 28 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc5-bk3
- Various compile fixes for building with gcc-4.0

* Sat Feb 26 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc5-bk1

* Fri Feb 25 2005 Dave Jones <davej@redhat.com>
- Hopefully fix the zillion unresolved symbols. (#149758)

* Thu Feb 24 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc5

* Wed Feb 23 2005 Rik van Riel <riel@redhat.com>
- get rid of unknown symbols in kernel-xen0 (#149495)

* Wed Feb 23 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk11

* Mon Feb 21 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk9

* Sat Feb 19 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk7

* Sat Feb 19 2005 Rik van Riel <riel@redhat.com>
- upgrade to newer Xen code, needs xen-20050218 to run

* Sat Feb 19 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk6

* Fri Feb 18 2005 David Woodhouse <dwmw2@redhat.com>
- Add SMP kernel for PPC32

* Fri Feb 18 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk5

* Tue Feb 15 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk3

* Mon Feb 14 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk2

* Sun Feb 13 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4-bk1

* Sat Feb 12 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc4

* Fri Feb 11 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk8

* Thu Feb 10 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk7

* Wed Feb  9 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk6

* Tue Feb  8 2005 Dave Jones <davej@redhat.com>
- Enable old style and new style USB initialisation.
- More PPC jiggery pokery hackery.
- 2.6.11-rc3-bk5

* Mon Feb  7 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk4
- Various patches to unbork PPC.
- Display taint bits on VM error.

* Mon Feb  7 2005 Rik van Riel <riel@redhat.com>
- upgrade to latest upstream Xen bits, upgrade those to 2.6.11-rc3-bk2

* Sat Feb  5 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk2

* Fri Feb  4 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc3-bk1

* Wed Feb  2 2005 Dave Jones <davej@redhat.com>
- Stop the input layer spamming the console. (#146906)
- 2.6.11-rc3

* Tue Feb  1 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc2-bk10
- Reenable periodic slab checker.

* Tue Feb  1 2005 Rik van Riel <riel@redhat.com>
- update to latest xen-unstable source snapshot
- add agpgart patch from upstream xen tree
- port Ingo's latest execshield updates to Xen

* Mon Jan 31 2005 Rik van Riel <riel@redhat.com>
- enable SMP support in xenU kernel, use the xen0 kernel for the
  unprivileged domains if the SMP xenU breaks on your system

* Thu Jan 27 2005 Dave Jones <davej@redhat.com>
- Drop VM hack that broke in yesterdays rebase.

* Wed Jan 26 2005 Dave Jones <davej@redhat.com>
- Drop 586-SMP kernels.  These are a good candidate for
  fedora-extras when it appears. The number of people
  actually using this variant is likely to be very very small.
- 2.6.11-rc2-bk4

* Tue Jan 25 2005 Dave Jones <davej@redhat.com>
- 2.6.11-rc2-bk3

* Sun Jan 23 2005 Dave Jones <davej@redhat.com>
- Updated periodic slab debug check from Manfred.
- Enable PAGE_ALLOC debugging again, it should now be fixed.
- 2.6.11-rc2-bk1

* Fri Jan 21 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.11-rc2

* Fri Jan 21 2005 Rik van Riel <riel@redhat.com>
- make exec-shield segment limits work inside the xen kernels

* Thu Jan 20 2005 Dave Jones <davej@redhat.com>
- Rebase to -bk8

* Wed Jan 19 2005 Dave Jones <davej@redhat.com>
- Re-add diskdump/netdump based on Jeff Moyers patches.
- Rebase to -bk7

* Tue Jan 18 2005 Jeremy Katz <katzj@redhat.com>
- fixup xen0 %%post to use new grubby features for multiboot kernels
- conflict with older mkinitrd for kernel-xen0

* Tue Jan 18 2005 Dave Jones <davej@redhat.com>
- -bk6

* Mon Jan 17 2005 Dave Jones <davej@redhat.com>
- First stab at kernel-devel packages. (David Woodhouse).

* Mon Jan 17 2005 Rik van Riel <riel@redhat.com>
- apply dmi fix, now xenU boots again

* Fri Jan 14 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.11-bk2

* Thu Jan 13 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.11-bk1

* Wed Jan 12 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.11rc1

* Tue Jan 11 2005 Rik van Riel <riel@redhat.com>
- fix Xen compile with -bk14

* Tue Jan 11 2005 Dave Jones <davej@redhat.com>
- Update to -bk14
- Print tainted information in slab corruption messages.

* Tue Jan 11 2005 Rik van Riel <riel@redhat.com>
- merge fix for the Xen TLS segment fixup issue

* Tue Jan 11 2005 Dave Jones <davej@redhat.com>
- Depend on hardlink, not kernel-utils.

* Mon Jan 10 2005 Dave Jones <davej@redhat.com>
- Update to -bk13, reinstate GFP_ZERO patch which hopefully
  is now fixed.
- Add another Lexar card reader to the whitelist. (#143600)
- Package asm-m68k for asm-ppc includes. (don't ask). (#144604)

* Sat Jan  8 2005 Dave Jones <davej@redhat.com>
- Periodic slab debug is incompatable with pagealloc debug.
  Disable the latter.

* Fri Jan  7 2005 Dave Jones <davej@redhat.com>
- Santa came to Notting's house too. (another new card reader)
- Rebase to 2.6.10-bk10

* Thu Jan  6 2005 Rik van Riel <riel@redhat.com>
- update to latest xen-unstable tree
- fix up Xen compile with -bk9, mostly pudding

* Thu Jan  6 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10-bk9

* Tue Jan  4 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10-bk7
- Add periodic slab debug checker.

* Sun Jan  2 2005 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10-bk5

* Sat Jan  1 2005 Dave Jones <davej@redhat.com>
- Fix probing of vesafb. (#125890)
- Reenable EDD.
- Don't assume existance of ~/.gnupg (#142201)

* Fri Dec 31 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10-bk4

* Thu Dec 30 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10-bk3

* Tue Dec 28 2004 Dave Jones <davej@redhat.com>
- Drop bogus ethernet slab cache.

* Sun Dec 26 2004 Dave Jones <davej@redhat.com>
- Santa brought a new card reader that needs whitelisting.

* Fri Dec 24 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.10

* Wed Dec 22 2004 Dave Jones <davej@redhat.com>
- Re-add missing part of the exit() race fix. (#142505, #141896)

* Tue Dec 21 2004 Dave Jones <davej@redhat.com>
- Fix two silly bugs in the AGP posting fixes.

* Fri Dec 17 2004 Dave Jones <davej@redhat.com>
- Fix bio error propagation.
- Clear ebp on sysenter return.
- Extra debugging info on OOM kill.
- exit() race fix.
- Fix refcounting order in sd/sr, fixing cable pulls on USB storage.
- IGMP source filter fixes.
- Fix ext2/3 leak on umount.
- fix missing wakeup in ipc/sem
- Fix another tux corner case bug.
- NULL out ptrs in airo driver after kfree'ing them.

* Thu Dec 16 2004 Dave Jones <davej@redhat.com>
- Better version of the PCI Posting fixes for AGPGART.
- Add missing cache flush to the AGP code.
- Drop netdump and common crashdump code.

* Mon Dec 13 2004 Dave Jones <davej@redhat.com>
- Drop diskdump. Aiming for a better kexec based solution for FC4.

* Sun Dec 12 2004 Dave Jones <davej@redhat.com>
- fix false ECHILD result from wait* with zombie group leader.

* Sat Dec 11 2004 Dave Jones <davej@redhat.com>
- Workaround broken pci posting in AGPGART.
- Compile 686 kernel tuned for pentium4.
  | Needs benchmarking across various CPUs under
  | various workloads to find out if its worth keeping.
- Make sure VC resizing fits in s16.

* Fri Dec 10 2004 Dave Jones <davej@redhat.com>
- Prevent block device queues from being shared in viocd. (#139018)
- Libata updates. (#132848, #138405)
- aacraid: remove aac_handle_aif (#135527)
- fix uninitialized variable in waitid(2). (#142505)
- Fix CMSG validation checks wrt. signedness.
- Fix memory leak in ip_conntrack_ftp
- [IPV4]: Do not leak IP options.
- ppc64: Align PACA buffer for hypervisor's use. (#141817)
- ppc64: Indicate that the veth link is always up. (#135402)
- ppc64: Quiesce OpenFirmware stdin device at boot. (#142009)
- SELinux: Fix avc_node_update oops. (#142353)
- Fix CCISS ioctl return code.
- Make ppc64's pci_alloc_consistent() conform to documentation. (#140047)
- Enable EDD
- Enable ETH1394. (#138497)
- Workaround E1000 post-maturely writing back to TX descriptors. (#133261)
- Fix the previous E1000 errata workaround.
- Several IDE fixes from 2.6.9-ac
- vm pageout throttling. (#133858)
- Fix Tux from oopsing. (#140918)
- Fix Tux/SELinux incompatability (#140916)
- Fix Tux/IPV6 problem. (#140916)
- ide: Fix possible oops on boot.
- Make spinlock debugging panic instead of printk.
- Update Emulex lpfc driver to 8.0.16
- Selected patches from 2.6.9-ac12
- ppc64: Fix inability to find space for TCE table (#138844)
- Fix compat fcntl F_GETLK{,64} (#141680)
- blkdev_get_blocks(): handle eof
- Another card reader for the whitelist. (#134094)
- Disable tiglusb module. (#142102)
- E1000 64k-alignment fix. (#140047)
- Disable tiglusb module. (#142102)
- ID updates for cciss driver.
- Fix overflows in USB Edgeport-IO driver. (#142258)
- Fix wrong TASK_SIZE for 32bit processes on x86-64. (#141737)
- Fix ext2/ext3 xattr/mbcache race. (#138951)
- Fix bug where __getblk_slow can loop forever when pages are partially mapped. (#140424)
- Add missing cache flushes in agpgart code.

* Thu Dec  9 2004 Dave Jones <davej@redhat.com>
- Drop the 4g/4g hugemem kernel completely.

* Wed Dec  8 2004 Rik van Riel <riel@redhat.com>
- make Xen inherit config options from x86

* Mon Dec  6 2004 Rik van Riel <riel@redhat.com>
- apparently Xen works better without serial drivers in domain0 (#141497)

* Sun Dec  5 2004 Rik van Riel <riel@redhat.com>
- Fix up and reenable Xen compile.
- Fix bug in install part of BuildKernel. 

* Sat Dec  4 2004 Dave Jones <davej@redhat.com>
- Enable both old and new megaraid drivers.
- Add yet another card reader to usb scsi whitelist. (#141367)

* Fri Dec  3 2004 Dave Jones <davej@redhat.com>
- Sync all patches with latest updates in FC3.
- Fix up xen0/xenU uninstall.
- Temporarily disable xen builds.

* Wed Dec  1 2004 Rik van Riel <riel@redhat.com>
- replace VM hack with the upstream version
- more Xen bugfixes

* Tue Nov 30 2004 Rik van Riel <riel@redhat.com>
- upgrade to later Xen sources, with upstream bugfixes
- export direct_remap_area_pages for Xen

* Mon Nov 29 2004 Dave Jones <davej@redhat.com>
- Add another card reader to whitelist. (#141022)

* Fri Nov 26 2004 Rik van Riel <riel@redhat.com>
- add Xen kernels for i686, plus various bits and pieces to make them work

* Mon Nov 15 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-ac9

* Sat Nov 13 2004 Dave Jones <davej@redhat.com>
- Drop some bogus patches.

* Thu Nov 11 2004 Dave Jones <davej@redhat.com>
- NFS: Fix dentry refcount accounting error
- Fix single-stepping on PPC64
- Integrate kernel-devel changes
- SELinux: netif fixes.
- SELinux: add DAC check to setxattr() hook.
- SELinux: sidtab locking fix.
- SELinux: mediate send_sigurg().
- SELinux: fix setscheduler hook deadlock.
- ide-floppy: Supresses error messages resulting from Medium not present
- Various IA64 updates from 2.6.10rc1
- nfsd: make sure getxattr inode op is non-NULL before calling it.
- Handle NULL dev->dev_addr in SIOCGIFHWADDR correctly. (#137648)
- Fix NFSD domainname size limit.
- nfsd4: nfsd oopsed when encountering a conflict with a local lock
- nfsd4: fix putrootfh return
- nfsd: Insecure port warning shows decimal IPv4 address
- Disable sw irqbalance/irqaffinity for e7520/e7320/e7525 (#136419)
- Fix exec-shield non-PIE/non-prelinked bug
- ext3 reservations: fix goal hit accounting.
- Fix problems with non-power-of-two sector size discs. (#135094)
- Fix possible oops in netpoll (#132153)
- Add missing MODULE_VERSION tags to various modules. (#136399)
- Add USB card reader de jour. (#124048)
- Remove SG_IO deprecation warning (#136179)
- Make sure that modules get signed with the right key.
- Remove SG_IO deprecation warning (#136179)
- s390: Fix fake_ll for qeth device. (#136175)
- s390: zfcp: Kernel stack frame for zfcp_cfdc_dev_ioctl() is too big
- s390: Use slab allocator for DASD I/O pages.
- PPC64: HVSI udbg support
- PPC64: Make HVSI console survive FSP reset
- PPC64: Make PCI hostbridge hotplugging work
- PPC64: Fix IBM VSCSI problems (#138124)
- Rebase -ac patch to 2.6.9-ac8.

* Wed Nov  3 2004 Dave Jones <davej@redhat.com>
- Reenable token-ring drivers (#122602)

* Tue Nov  2 2004 Dave Jones <davej@redhat.com>
- Reenable SLIP. (#124223)
- Add USB card reader de jour. (#124048)

* Mon Nov  1 2004 Dave Jones <davej@redhat.com>
- Fix memory leak on x86-64 in mixed 32/64 mode. (#132947)
- Yet another USB card reader for the whitelist. (#137722)

* Fri Oct 29 2004 Dave Jones <davej@redhat.com>
- Fix raid5 oops (#127862)
- Stop E820 BIOS entries being corrupted by EDID info. (#137510)

* Thu Oct 28 2004 Dave Jones <davej@redhat.com>
- Remove the possibility of some false OOM kills. (#131251)
- Add more USB card readers to SCSI whitelist (#131546)
- Disable CONFIG_SCHED_SMT for iseries.

* Wed Oct 27 2004 Dave Jones <davej@redhat.com>
- Reenable ISA NIC support (#136569)

* Tue Oct 26 2004 Dave Jones <davej@redhat.com>
- Reenable Initio 9100U(W) SCSI driver. (#137153)

* Mon Oct 25 2004 Dave Jones <davej@redhat.com>
- Add another USB card reader to SCSI whitelist (#132923)

* Fri Oct 22 2004 Dave Jones <davej@redhat.com>
- Fix PPC NUMA (#130716).
- Fix autoraid for S390 (#123842/#130339)
- Selected bits from 2.6.9-ac3
  - Fix syncppp/async ppp problems with new hangup
  - Fix broken parport_pc unload
  - Stop i8xx_tco making some boxes reboot on load
  - Fix cpia/module tools deadlock
  - Security fix for smbfs leak/overrun

* Thu Oct 21 2004 Dave Jones <davej@redhat.com>
- Misc security fixes from 2.6.9-ac2

* Wed Oct 20 2004 Dave Jones <davej@redhat.com>
- Fix ia64 module loading. (#136365)
- Enable discontigmem for PPC64
- Disable a bunch of useless PPC config options
- Enable PACK_STACK on s390.

* Tue Oct 19 2004 Dave Jones <davej@redhat.com>
- Fix NFS badness (#132726)
- Drop bogus USB workaround. (#131127)

* Mon Oct 18 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9
- Speedtouch USB DSL modem driver update.
- Cleanup some iseries config options.

* Fri Oct 15 2004 Dave Jones <davej@redhat.com>
- 2.6.9-rc4-bk3
- Fix up a bunch of unresolved symbols that crept in recently.
- Remove bogus O_NONBLOCK patch which broke lots of userspace.
- Fix booting on PPC64 by reserving initrd pages.

* Thu Oct 14 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk2
- librtas needs to work around the /dev/mem restrictions.
- EXT3 reservations use-before-initialised bugfix.
- support O_NONBLOCK for read,pread,readv of regular files.
- EDD blows up some x86-64's. Disable again.

* Wed Oct 13 2004 Dave Jones <davej@redhat.com>
- Make EDD driver modular on x86-64 too.
- Various mkinitrd spec changes (Jeremy Katz)
- Enable a bunch more PPC64 config options. (Dave Howells)
- Enable ACPI cpufreq driver for x86-64 too.

* Tue Oct 12 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk1
- Tux update.
- Update netdump/diskdump patches
- PowerPC 64 netboot changes.
- Various CONFIG_ option diddling.
- Fix up the find_isa_irq_pin() oops on reboot for x86-64 too. 

* Mon Oct 11 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4
- Enable CONFIG_MICROCODE for x86-64

* Fri Oct  8 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk8

* Thu Oct  7 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk7
- Fix up PPC/PPC64 compilation failures due to new binutils. (David Woodhouse)

* Wed Oct  6 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk6
- Add xattr support for tmpfs.

* Mon Oct  4 2004 Stephen C. Tweedie <sct@redhat.com>
- Update ext3 online resize to 2.6.9-rc3-mm2 upstream
- Reenable ext3 online resize in .spec

* Tue Sep 28 2004 Jeremy Katz <katzj@redhat.com>
- add patch from Roland McGrath/James Morris to fix mprotect hook bug (#133505)

* Mon Sep 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2-bk5

* Thu Sep 16 2004 Arjan van de Ven <arjanv@redhat.com>
- fix tux for x86-64 and ppc64

* Tue Sep 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2
- add diskdump

* Fri Sep 10 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk17 ; make ppc32 build

* Tue Sep 07 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk13

* Mon Sep 06 2004 Arjan van de Ven <arjanv@redhat.com>
- disable online resize again
- hopefully fix Quake3 interaction with execshield
- add Alan's borken-bios-IRQ workaround patch

* Sat Sep 04 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk11

* Tue Aug 31 2004 Arjan van de Ven <arjanv@redhat.com>
- fix execshield buglet with legacy binaries
- 2.6.9-rc1-bk7

* Mon Aug 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk6

* Sat Aug 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk4, now with i915 DRM driver

* Fri Aug 27 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk2 

* Mon Aug 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8.1-bk2

* Sat Aug 21 2004 Arjan van de Ven <arjanv@redhat.com>
- attempt to fix early-udev bug

* Fri Aug 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc4-bk3
- split execshield up some more

* Fri Aug 13 2004 Dave Jones <davej@redhat.com>
- Update SCSI whitelist again with some more card readers.

* Mon Aug 9 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc3-bk3

* Wed Aug 4 2004 Arjan van de Ven <arjanv@redhat.com>
- Add the flex-mmap bits for s390/s390x (Pete Zaitcev)
- Add flex-mmap for x86-64 32 bit emulation
- 2.6.8-rc3

* Mon Aug 2 2004 Arjan van de Ven <arjanv@redhat.com>
- Add Rik's token trashing control patch

* Sun Aug 1 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk11

* Fri Jul 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk8

* Wed Jul 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk6
- make a start at splitting up the execshield patchkit

* Fri Jul 16 2004 Arjan van de Ven <arjanv@redhat.com>
- ppc32 embedded updates

* Thu Jul 15 2004 Arjan van de Ven <arjanv@redhat.com>
- make USB modules again and add Alan's real fix for the SMM-meets-USB bug
- 2.6.8-rc1-bk4

* Wed Jul 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc1-bk3

* Tue Jul 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add "enforcemodulesig" boot option to make the kernel load signed modules only

* Mon Jul 12 2004 Arjan van de Ven <arjanv@redhat.com>
- updated voluntary preempt
- 2.6.8-rc1

* Wed Jul 7 2004 Arjan van de Ven <arjanv@redhat.com>
- fix boot breakage that was hitting lots of people (Dave Jones)

* Tue Jul 6 2004 Arjan van de Ven <arjanv@redhat.com>
- add voluntary preemption patch from Ingo
- 2.6.7-bk19

* Tue Jun 29 2004 Arjan van de Ven <arjanv@redhat.com>
- make a start at gpg signed modules support

* Sat Jun 27 2004 Arjan van de Ven <arjanv@redhat.com>
- experiment with making the hardlink call in post more efficient
- 2.6.7-bk9

* Thu Jun 24 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk7
- Add wli's patch to allocate memory bottom up not top down
- change some config options in the kernel-sourcecode package that are
  good for rpm kernel builds but not for custom user builds to more appropriate 
  default values.
- reenable kernel-sourcecode again for a few builds 

* Wed Jun 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk5
- fix tux unresolved symbols (#126532)

* Mon Jun 21 2004 Arjan van de Ven <arjanv@redhat.com>
- make kernel-doc and kernel-sourcecode builds independent of eachother
- disable kernel-sourcecode builds entirely, we'll be replacing it with documentation
  on how to use the src.rpm instead for building your own kernel.

* Sat Jun 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk2

* Sun Jun 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add patch from DaveM to fix the ppp-keeps-iface-busy bug

* Sat Jun 12 2004 Arjan van de Ven <arjanv@redhat.com>
- add fix from Andi Kleen/Linus for the fpu-DoS

* Thu Jun 10 2004 Arjan van de Ven <arjanv@redhat.com>
- disable mlock-uses-rlimit patch, it has a security hole and needs more thought
- revert airo driver to the FC2 one since the new one breaks

* Tue Jun 8 2004 Dave Jones <davej@redhat.com>
- Update to 2.6.7rc3

* Fri Jun 4 2004 Arjan van de Ven <arjanv@redhat.com>
- fix the mlock-uses-rlimit patch

* Wed Jun 2 2004 David Woodhouse <dwmw2@redhat.com>
- Add ppc64 (Mac G5)

* Wed Jun 2 2004 Arjan van de Ven <arjanv@redhat.com>
- add a forward port of the mlock-uses-rlimit patch
- add NX support for x86 (Intel, Ingo)

* Tue Jun 1 2004 Arjan van de Ven <arjanv@redhat.com>
- refresh ext3 reservation patch

* Sun May 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-rc2
- set the ACPI OS name to "Microsoft Windows XP" for better compatibility

* Thu May 27 2004 Pete Zaitcev <zaitcev@redhat.com>
- Fix qeth and zfcp (s390 drivers): align qib by 256, embedded into qdio_irq.

* Thu May 27 2004 Dave Jones <davej@redhat.com>
- Fix the crashes on boot on Asus P4P800 boards. (#121819)

* Wed May 26 2004 Dave Jones <davej@redhat.com>
- Lots more updates to the SCSI whitelist for various
  USB card readers. (#112778, among others..)

* Wed May 26 2004 Arjan van de Ven <arjanv@redhat.com>
- back out ehci suspend/resume patch, it breaks
- add fix for 3c59x-meets-kudzu bug from Alan

* Tue May 25 2004 Arjan van de Ven <arjanv@redhat.com>
- try improving suspend/resume by restoring more PCI state
- 2.6.7-rc1-bk1

* Mon May 24 2004 Dave Jones <davej@redhat.com>
- Add yet another multi-card reader to the whitelist (#85851)

* Sun May 23 2004 Dave Jones <davej@redhat.com>
- Add another multi-card reader to the whitelist (#124048)

* Wed May 19 2004 Arjan van de Ven <arjanv@redhat.com>
- put firewire race fix in (datacorruptor)

* Tue May 18 2004 Dave Jones <davej@redhat.com>
- Fix typo in ibmtr driver preventing compile (#123391)

* Mon May 17 2004 Arjan van de Ven <arjanv@redhat.com>
- update to 2.6.6-bk3
- made kernel-source and kernel-doc noarch.rpm's since they are not
  architecture specific.

* Sat May 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix non-booting on Transmeta cpus (Peter Anvin)
- fix count leak in message queues

* Fri May 07 2004 Arjan van de Ven <arjanv@redhat.com>
- more ide cache flush work
- patch from scsi-bk to fix sd refcounting

* Thu May 06 2004 Arjan van de Ven <arjanv@redhat.com>
- some more ide cache flush fixes 

* Wed May 05 2004 Arjan van de Ven <arjanv@redhat.com>
- fix bug 122504
- convert b44 to ethtool ops (jgarzik)
- make IDE do a cache-flush on shutdown (me/Alan)

* Tue May 04 2004 Arjan van de Ven <arjanv@redhat.com>
- work around i810/i830 DRM issue

* Fri Apr 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc3-bk1
- make amd64 boot again
- fix vm86-vs-4g4g interaction (Ingo)

* Thu Apr 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc2
 
* Tue Apr 20 2004 Arjan van de Ven <arjanv@redhat.com>
- add the ext3 online resize patch

* Mon Apr 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc1-bk3
- add the objrmap vm from the -mm tree; it needs testing

* Thu Apr 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-bk2
- disable DISCONTIGMEM on ia64 for performance
- fix sleep_on use in reiserfs (Chris Mason)

* Tue Apr 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc4
- reenable sg driver for scsi tape changers and such
- the sk98lin driver oopses on module unload, preven that

* Mon Apr 12 2004 Arjan van de Ven <arjanv@redhat.com>
- fix "bad pmd" bug with patch from Ingo

* Fri Apr 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc3
- finish up the -mc2 merge
- latest 4g/4g patch from Ingo
- latest execshield patch from Ingo
- fix a few framebuffer bugs

* Thu Apr 08 2004 Arjan van de Ven <arjanv@redhat.com>
- first attempt at a 2.6.5-mc2 merge

* Thu Apr 08 2004 Dave Jones <davej@redhat.com>
- Add in missing SiS AGP fix.

* Tue Apr 06 2004 Dave Jones <davej@redhat.com>
- More agpgart fixes.

* Fri Apr 02 2004 Arjan van de Ven <arjanv@redhat.com>
- fix another 4g/4g-vs-resume bug

* Tue Mar 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc3
- fix PCI posting bug in i830 DRM

* Mon Mar 29 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk8

* Mon Mar 29 2004 Dave Jones <davej@redhat.com>
- Include latest agpgart fixes.

* Thu Mar 25 2004 Arjan van de Ven <arjanv@redhat.com>
- more DRM fixes
- add the fsync patches from akpm

* Tue Mar 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk3
- fix direct userspace memory access in i830 drm driver

* Mon Mar 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk2
- some stackbloat reductions from Dave and me

* Sat Mar 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2

* Tue Mar 16 2004 Dave Jones <davej@redhat.com>
- 2.6.5-rc1

* Mon Mar 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk3
- fix oops in toshiba_acpi (Barry K. Nathan)

* Sat Mar 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk2 merge 

* Thu Mar 11 2004 Arjan van de Ven <arjanv@redhat.com>
- renable sonypi driver that was off accidentally
- 2.6.4-final 
- fix the oops on alsa module unloads

* Wed Mar 10 2004 Arjan van de Ven <arjanv@redhat.com>
- add ppc64/iseries, ppc32 (powermac/ibook) and ia64 architectures
- 2.6.4-rc3 

* Tue Mar 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-rc2-bk5
- fix nfs-vs-selinux issue
- fix typo in URL as per #117849

* Mon Mar 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix race in lp.c (#117710)
- 2.6.4-rc2-bk3
- attempt to fix S3 suspend-to-ram with 4g/4g split

* Sat Mar 06 2004 Arjan van de Ven <arjanv@redhat.com>
- fix reiserfs
- set HZ to 1000 again for some tests

* Wed Feb 25 2004 Arjan van de Ven <arjanv@redhat.com>
- merge back a bunch of fedora fixes
- disable audit

* Tue Feb 24 2004 Arjan van de Ven <arjanv@redhat.com>
- audit bugfixes
- update tux to a working version
- 2.6.3-bk5 merge

* Fri Feb 20 2004 Arjan van de Ven <arjanv@redhat.com>
- re-add and enable the Auditing patch
- switch several cpufreq modules to built in since detecting in userspace
  which to use is unpleasant

* Thu Jul 03 2003 Arjan van de Ven <arjanv@redhat.com>
- 2.6 start

